=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2012-07-10 12:19:23 +0000
+++ bzrlib/__init__.py	2012-06-18 11:43:07 +0000
@@ -55,7 +55,7 @@
 # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
 # releaselevel of 'dev' for unreleased under-development code.
 
-version_info = (2, 6, 0, 'dev', 3)
+version_info = (2, 6, 0, 'dev', 2)
 
 # API compatibility version
 api_minimum_version = (2, 4, 0)

=== modified file 'bzrlib/plugins/launchpad/cmds.py'
--- bzrlib/plugins/launchpad/cmds.py	2012-07-20 15:09:13 +0000
+++ bzrlib/plugins/launchpad/cmds.py	2012-03-12 14:35:26 +0000
@@ -335,15 +335,16 @@
     __doc__ = """Find the proposal to merge this revision.
 
     Finds the merge proposal(s) that discussed landing the specified revision.
-    This works only if the if the merged_revno was recorded for the merge
-    proposal.  The proposal(s) are opened in a web browser.
+    This works only if the selected branch was the merge proposal target, and
+    if the merged_revno is recorded for the merge proposal.  The proposal(s)
+    are opened in a web browser.
 
-    Only the revision specified is searched for.  To find the mainline
-    revision that merged it into mainline, use the "mainline" revision spec.
+    Any revision involved in the merge may be specified-- the revision in
+    which the merge was performed, or one of the revisions that was merged.
 
     So, to find the merge proposal that reviewed line 1 of README::
 
-      bzr lp-find-proposal -r mainline:annotate:README:1
+      bzr lp-find-proposal -r annotate:README:1
     """
 
     takes_options = ['revision']
@@ -356,11 +357,8 @@
         pb = ui.ui_factory.nested_progress_bar()
         b.lock_read()
         try:
-            if revision is None:
-                revision_id = b.last_revision()
-            else:
-                revision_id = revision[0].as_revision_id(b)
-            merged = self._find_proposals(revision_id, pb)
+            revno = self._find_merged_revno(revision, b, pb)
+            merged = self._find_proposals(revno, b, pb)
             if len(merged) == 0:
                 raise BzrCommandError(gettext('No review found.'))
             trace.note(gettext('%d proposals(s) found.') % len(merged))
@@ -370,10 +368,43 @@
             b.unlock()
             pb.finished()
 
-    def _find_proposals(self, revision_id, pb):
+    def _find_merged_revno(self, revision, b, pb):
+        if revision is None:
+            return b.revno()
+        pb.update(gettext('Finding revision-id'))
+        revision_id = revision[0].as_revision_id(b)
+        # a revno spec is necessarily on the mainline.
+        if self._is_revno_spec(revision[0]):
+            merging_revision = revision_id
+        else:
+            graph = b.repository.get_graph()
+            pb.update(gettext('Finding merge'))
+            merging_revision = graph.find_lefthand_merger(
+                revision_id, b.last_revision())
+            if merging_revision is None:
+                raise InvalidRevisionSpec(revision[0].user_spec, b)
+        pb.update(gettext('Finding revno'))
+        return b.revision_id_to_revno(merging_revision)
+
+    def _find_proposals(self, revno, b, pb):
         from bzrlib.plugins.launchpad import (lp_api, lp_registration)
-        launchpad = lp_api.login(lp_registration.LaunchpadService(),
-                                 version='devel')
+        launchpad = lp_api.login(lp_registration.LaunchpadService())
+        pb.update(gettext('Finding Launchpad branch'))
+        lpb = lp_api.LaunchpadBranch.from_bzr(launchpad, b,
+                                              create_missing=False)
         pb.update(gettext('Finding proposals'))
-        return list(launchpad.branches.getMergeProposals(
-                    merged_revision=revision_id))
+        return list(lpb.lp.getMergeProposals(status=['Merged'],
+                                             merged_revnos=[revno]))
+
+
+    @staticmethod
+    def _is_revno_spec(spec):
+        try:
+            int(spec.user_spec)
+        except ValueError:
+            return False
+        else:
+            return True
+
+
+

=== modified file 'bzrlib/plugins/launchpad/lp_api.py'
--- bzrlib/plugins/launchpad/lp_api.py	2012-07-20 15:09:13 +0000
+++ bzrlib/plugins/launchpad/lp_api.py	2011-12-19 13:23:58 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2012 Canonical Ltd
+# Copyright (C) 2009, 2010 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,12 +49,12 @@
     STAGING_SERVICE_ROOT,
     Launchpad,
     )
-from launchpadlib import uris
+
 
 # Declare the minimum version of launchpadlib that we need in order to work.
-# 1.6.0 is the version of launchpadlib packaged in Ubuntu 10.04, the most
-# recent Ubuntu LTS release supported on the desktop at the time of writing.
-MINIMUM_LAUNCHPADLIB_VERSION = (1, 6, 0)
+# 1.5.1 is the version of launchpadlib packaged in Ubuntu 9.10, the most
+# recent Ubuntu release at the time of writing.
+MINIMUM_LAUNCHPADLIB_VERSION = (1, 5, 1)
 
 
 def get_cache_directory():
@@ -76,14 +76,28 @@
             installed_version, installed_version)
 
 
-def lookup_service_root(service_root):
-    try:
-        return uris.lookup_service_root(service_root)
-    except ValueError:
-        if service_root != 'qastaging':
-            raise
-        staging_root = uris.lookup_service_root('staging')
-        return staging_root.replace('staging', 'qastaging')
+# The older versions of launchpadlib only provided service root constants for
+# edge and staging, whilst newer versions drop edge. Therefore service root
+# URIs for which we do not always have constants are derived from the staging
+# one, which does always exist.
+#
+# It is necessary to derive, rather than use hardcoded URIs because
+# launchpadlib <= 1.5.4 requires service root URIs that end in a path of
+# /beta/, whilst launchpadlib >= 1.5.5 requires service root URIs with no path
+# info.
+#
+# Once we have a hard dependency on launchpadlib >= 1.5.4 we can replace all of
+# bzr's local knowledge of individual Launchpad instances with use of the
+# launchpadlib.uris module.
+LAUNCHPAD_API_URLS = {
+    'production': STAGING_SERVICE_ROOT.replace('api.staging.launchpad.net',
+        'api.launchpad.net'),
+    'qastaging': STAGING_SERVICE_ROOT.replace('api.staging.launchpad.net',
+        'api.qastaging.launchpad.net'),
+    'staging': STAGING_SERVICE_ROOT,
+    'dev': STAGING_SERVICE_ROOT.replace('api.staging.launchpad.net',
+        'api.launchpad.dev'),
+    }
 
 
 def _get_api_url(service):
@@ -100,8 +114,8 @@
     else:
         lp_instance = service._lp_instance
     try:
-        return lookup_service_root(lp_instance)
-    except ValueError:
+        return LAUNCHPAD_API_URLS[lp_instance]
+    except KeyError:
         raise InvalidLaunchpadInstance(lp_instance)
 
 
@@ -112,8 +126,7 @@
         errors.BzrError.__init__(self, branch=branch, url=branch.base)
 
 
-def login(service, timeout=None, proxy_info=None,
-          version=Launchpad.DEFAULT_VERSION):
+def login(service, timeout=None, proxy_info=None):
     """Log in to the Launchpad API.
 
     :return: The root `Launchpad` object from launchpadlib.
@@ -121,9 +134,9 @@
     cache_directory = get_cache_directory()
     launchpad = Launchpad.login_with(
         'bzr', _get_api_url(service), cache_directory, timeout=timeout,
-        proxy_info=proxy_info, version=version)
-    # XXX: Work-around a minor security bug in launchpadlib < 1.6.3, which
-    # would create this directory with default umask.
+        proxy_info=proxy_info)
+    # XXX: Work-around a minor security bug in launchpadlib 1.5.1, which would
+    # create this directory with default umask.
     osutils.chmod_if_possible(cache_directory, 0700)
     return launchpad
 
@@ -197,7 +210,7 @@
         if str(launchpad._root_uri) == STAGING_SERVICE_ROOT:
             return url.replace('bazaar.launchpad.net',
                                'bazaar.staging.launchpad.net')
-        elif str(launchpad._root_uri) == lookup_service_root('qastaging'):
+        elif str(launchpad._root_uri) == LAUNCHPAD_API_URLS['qastaging']:
             return url.replace('bazaar.launchpad.net',
                                'bazaar.qastaging.launchpad.net')
         return url

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2012-07-11 07:06:56 +0000
+++ doc/developers/releasing.txt	2012-03-12 08:10:02 +0000
@@ -239,10 +239,10 @@
 #. Update the ``./doc/en/release-notes/`` section for this release.
 
    Check that all news entries related to this release have been added in
-   the right section. For example, if you're releasing 2.6b2, the following
-   command should display a a single chuk diff for the 2.6b2 release::
+   the right section. For example, if you're releasing 2.6b1, the following
+   command should display a a single chuk diff for the 2.6b1 release::
 
-     bzr diff -rbzr-2.6b2.. doc/en/release-notes/bzr-2.6.txt
+     bzr diff -rbzr-2.6b1.. doc/en/release-notes/bzr-2.6.txt
 
    Fill out the date and a description of the release under the existing
    header (the diff above will help you summarizing). If there isn't one,
@@ -558,7 +558,7 @@
      cd /srv/doc.bazaar.canonical.com/
      bzr branch http://bazaar.launchpad.net/~bzr-pqm/bzr/2.5 bzr.2.5
 
-   And the ``bzr/bin/update-bzr-docs`` script needs to refer to it.
+   And the ``update-bzr-docs`` needs to refer to it.
 
    The ``lp:bzr-alldocs`` branch also needs to be updated when a new series
    is introduced, see the ``README`` file there for more instructions
@@ -725,8 +725,6 @@
    button and select the right Ubuntu release. As of September 2010, this
    means:
 
-  * ``quantal`` for the 2.6 series,
-  * ``precise`` for the 2.5 series,
   * ``oneiric`` for the 2.4 series,
   * ``natty`` for the 2.3 series,
   * ``maverick`` for the 2.2 series,

=== modified file 'doc/en/release-notes/bzr-2.6.txt'
--- doc/en/release-notes/bzr-2.6.txt	2012-07-23 19:00:53 +0000
+++ doc/en/release-notes/bzr-2.6.txt	2012-07-05 15:44:32 +0000
@@ -5,10 +5,10 @@
 .. toctree::
    :maxdepth: 1
 
-bzr 2.6b3
+bzr 2.6b2
 #########
 
-:2.6b3: NOT RELEASED YET
+:2.6b2: NOT RELEASED YET
 
 External Compatibility Breaks
 *****************************
@@ -20,80 +20,24 @@
 
 .. New commands, options, etc that users may wish to try out.
 
+* New option ``--overwrite-tags`` for ``bzr pull`` and ``bzr push``.
+  (Jelmer Vernooij, #681792)
+
 Improvements
 ************
 
 .. Improvements to existing commands, especially improved performance 
    or memory usage, or better results.
 
+* Colocated branches can now be addressed using the 'co:NAME' rather than
+  the more complex 'file://.,branch=NAME'. (Jelmer Vernooij, #833665)
+
 Bug Fixes
 *********
 
 .. Fixes for situations where bzr would previously crash or give incorrect
    or undesirable results.
 
-Documentation
-*************
-
-.. Improved or updated documentation.
-
-API Changes
-***********
-
-.. Changes that may require updates in plugins or other code that uses
-   bzrlib.
-
-Internals
-*********
-
-* The launchpad plugin now requires API 1.6.0 or later.  This version shipped
-  with Ubuntu 9.10.  (Aaron Bentley)
-
-Testing
-*******
-
-.. Fixes and changes that are only relevant to bzr's test framework and 
-   suite.  This can include new facilities for writing tests, fixes to 
-   spurious test failures and changes to the way things should be tested.
-
-
-bzr 2.6b2
-#########
-
-:2.6b2: 2012-09-10
-
-This is the second beta for the 2.6 series, leading up to a 2.6.0 release in
-August 2012.
-
-This release includes minor bug fixes.
-
-This release includes all bugs fixed in previous series known at the time of
-this release.
-
-Beta releases are suitable for everyday use but may cause some
-incompatibilities with plugins.  Some plugins may need small updates to work
-with 2.6b2.
-
-External Compatibility Breaks
-*****************************
-
-None.
-
-New Features
-************
-
-* New option ``--overwrite-tags`` for ``bzr pull`` and ``bzr push``.
-  (Jelmer Vernooij, #681792)
-
-Improvements
-************
-
-* Colocated branches can now be addressed using the 'co:NAME' rather than
-  the more complex 'file://.,branch=NAME'. (Jelmer Vernooij, #833665)
-
-Bug Fixes
-*********
-
 * "bzr missing" now shows tag names when displaying revision information.
   (#559072, Neil Martinsen-Burrell)
 
@@ -103,50 +47,39 @@
 * Implement ``ResponseFile.readline`` and ``ReponseFile.tell``,
   fixing some clones over HTTP. (Jelmer Vernooij, #963769)
 
-* Option values set on locked branches should be saved only when the branch
-  is finally unlocked. (Vincent Ladeuil, #948339)
-
 
 Documentation
 *************
 
-* Document "bzr lp-propose", "bzr register-branch" and
-  the other Launchpad plugin commands in bzr(1).
-  (Jelmer Vernooij, #843801, #163995)
+.. Improved or updated documentation.
 
 * Force format registration to avoid generate_docs.py traceback when the
   registry is empty. (Vincent Ladeuil, #956860)
 
-* Generate ``ENVIRONMENT`` section in bzr(1) from known environment variable
-  list rather than hardcoding. (Jelmer Vernooij, #197618)
-
-
 API Changes
 ***********
 
-* ``register_filter_stack_map`` and ``lazy_register_filter_stack_map``
-  are noew deprecated. Instead, use ``filter_stacks_registry.register``
-  and ``filter_stacks_registry.register_lazy``.
-  (Jelmer Vernooij)
+.. Changes that may require updates in plugins or other code that uses
+   bzrlib.
+
+* Remove deprecated Repository.get_ancestry(). (Jelmer Vernooij)
 
 * Remove deprecated Branch.import_last_revision(). (Jelmer Vernooij)
 
+* Remove deprecated Repository.iter_reverse_revision_history().
+  (Jelmer Vernooij)
+
 * Remove deprecated ``RepositoryFormat.register_format``.
   (Jelmer Vernooij)
 
-* Remove deprecated Repository.get_ancestry(). (Jelmer Vernooij)
-
-* Remove deprecated Repository.iter_reverse_revision_history().
-  (Jelmer Vernooij)
-
 * The previously deprecated ``bzrlib.annotate.annotate_file`` function
   has been removed. (Jelmer Vernooij)
 
-
 Internals
 *********
 
-None.
+.. Major internal changes, unlikely to be visible to users or plugin 
+   developers, but interesting for bzr developers.
 
 Testing
 *******
@@ -212,9 +145,21 @@
 * Fix ``bzr config`` display for ``RegistryOption`` values.
   (Vincent Ladeuil, #930182)
 
+* Option values set on locked branches should be saved only when the branch
+  is finally unlocked. (Vincent Ladeuil, #948339)
+
 Documentation
 *************
 
+.. Improved or updated documentation.
+
+* Document "bzr lp-propose", "bzr register-branch" and
+  the other Launchpad plugin commands in bzr(1).
+  (Jelmer Vernooij, #843801, #163995)
+
+* Generate ``ENVIRONMENT`` section in bzr(1) from known environment variable
+  list rather than hardcoding. (Jelmer Vernooij, #197618)
+
 * Prevent lines of command descriptions starting with a dot to
   accidentally be interpreted as a roff macro in bzr(1).
   (Jelmer Vernooij, #711079)
@@ -243,6 +188,11 @@
 * New convenience API method ``WorkingTree.get_config_stack``.
   (Jelmer Vernooij)
 
+* ``register_filter_stack_map`` and ``lazy_register_filter_stack_map``
+  are noew deprecated. Instead, use ``filter_stacks_registry.register``
+  and ``filter_stacks_registry.register_lazy``.
+  (Jelmer Vernooij)
+
 * Remove 
   ``branch.PullResult.__int__`` deprecated in 2.3.0,
   ``branch.PushResult.__int__`` deprecated in 2.3.0,

=== modified file 'po/bzr.pot'
--- po/bzr.pot	2012-07-10 09:36:45 +0000
+++ po/bzr.pot	2012-03-15 09:23:14 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: bzr\n"
 "Report-Msgid-Bugs-To: <bazaar@canonical.com>\n"
-"POT-Creation-Date: 2012-07-10 11:35+0200\n"
+"POT-Creation-Date: 2012-03-15 10:20+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -26,36 +26,36 @@
 msgid "Unstacking"
 msgstr ""
 
-#: bzrlib/branch.py:2955
+#: bzrlib/branch.py:3121
 #, python-format
 msgid "Pushed up to revision %d."
 msgstr ""
 
-#: bzrlib/branch.py:2957
+#: bzrlib/branch.py:3123
 #, python-format
 msgid "%d tag updated."
 msgid_plural "%d tags updated."
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/branch.py:2960
+#: bzrlib/branch.py:3126
 msgid "No new revisions or tags to push."
 msgstr ""
 
-#: bzrlib/branch.py:2962
+#: bzrlib/branch.py:3128
 msgid "No new revisions to push."
 msgstr ""
 
-#: bzrlib/branch.py:2982
+#: bzrlib/branch.py:3148
 msgid "checked branch {0} format {1}"
 msgstr ""
 
-#: bzrlib/branch.py:2985
+#: bzrlib/branch.py:3151
 #, python-format
 msgid "found error:%s"
 msgstr ""
 
-#: bzrlib/builtins.py:251 bzrlib/builtins.py:3045 bzrlib/workingtree.py:323
+#: bzrlib/builtins.py:251 bzrlib/builtins.py:3026 bzrlib/workingtree.py:323
 #, python-format
 msgid "Ignoring files outside view. View is %s"
 msgstr ""
@@ -188,11 +188,11 @@
 msgid "bzr status --revision takes exactly one or two revision specifiers"
 msgstr ""
 
-#: bzrlib/builtins.py:441 bzrlib/builtins.py:5230
+#: bzrlib/builtins.py:441 bzrlib/builtins.py:5197
 msgid "You can only supply one of revision_id or --revision"
 msgstr ""
 
-#: bzrlib/builtins.py:444 bzrlib/builtins.py:5232
+#: bzrlib/builtins.py:444 bzrlib/builtins.py:5199
 msgid "You must supply either --revision or a revision_id"
 msgstr ""
 
@@ -268,7 +268,7 @@
 msgid "--tree and --revision can not be used together"
 msgstr ""
 
-#: bzrlib/builtins.py:688 bzrlib/builtins.py:5986
+#: bzrlib/builtins.py:688 bzrlib/builtins.py:5953
 msgid "Tags can only be placed on a single revision, not on a range"
 msgstr ""
 
@@ -521,60 +521,60 @@
 "master branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1189
+#: bzrlib/builtins.py:1180
 msgid "Need working tree for --show-base."
 msgstr ""
 
-#: bzrlib/builtins.py:1205
+#: bzrlib/builtins.py:1196
 msgid "No pull location known or specified."
 msgstr ""
 
-#: bzrlib/builtins.py:1211
+#: bzrlib/builtins.py:1202
 #, python-format
 msgid "Using saved parent location: %s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:1218 bzrlib/builtins.py:4425
+#: bzrlib/builtins.py:1209 bzrlib/builtins.py:4406
 msgid "Cannot use -r with merge directives or bundles"
 msgstr ""
 
-#: bzrlib/builtins.py:1261
+#: bzrlib/builtins.py:1252
 msgid "Update a mirror of this branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1263
+#: bzrlib/builtins.py:1254
 msgid ""
 "The target branch will not have its working tree populated because this\n"
 "is both expensive, and is not supported on remote file systems."
 msgstr ""
 
-#: bzrlib/builtins.py:1266
+#: bzrlib/builtins.py:1257
 msgid ""
 "Some smart servers or protocols *may* put the working tree in place in\n"
 "the future."
 msgstr ""
 
-#: bzrlib/builtins.py:1269
+#: bzrlib/builtins.py:1260
 msgid ""
 "This command only works on branches that have not diverged.  Branches are\n"
 "considered diverged if the destination branch's most recent commit is one\n"
 "that has not been merged (directly or indirectly) by the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1273
+#: bzrlib/builtins.py:1264
 msgid ""
 "If branches have diverged, you can use 'bzr push --overwrite' to replace\n"
 "the other branch completely, discarding its unmerged changes."
 msgstr ""
 
-#: bzrlib/builtins.py:1276
+#: bzrlib/builtins.py:1267
 msgid ""
 "If you want to ensure you have the different changes in the other branch,\n"
 "do a merge (see bzr help merge) from the other branch, and commit that.\n"
 "After that you will be able to do a push without '--overwrite'."
 msgstr ""
 
-#: bzrlib/builtins.py:1280
+#: bzrlib/builtins.py:1271
 msgid ""
 "If there is no default push location set, the first push will set it (use\n"
 "--no-remember to avoid setting it).  After that, you can omit the\n"
@@ -582,7 +582,7 @@
 "value will only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:1285
+#: bzrlib/builtins.py:1276
 msgid ""
 "The --verbose option will display the revisions pushed using the log_format\n"
 "configuration option. You can use a different format by overriding it with\n"
@@ -591,27 +591,27 @@
 
 # help of 'directory' option of 'dpush' command
 # help of 'directory' option of 'push' command
-#: bzrlib/builtins.py:1296 bzrlib/foreign.py:272
+#: bzrlib/builtins.py:1287 bzrlib/foreign.py:272
 msgid ""
 "Branch to push from, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'use-existing-dir' option of 'push' command
-#: bzrlib/builtins.py:1299
+#: bzrlib/builtins.py:1290
 msgid ""
 "By default push will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow push to proceed."
 msgstr ""
 
 # help of 'stacked' option of 'push' command
-#: bzrlib/builtins.py:1304
+#: bzrlib/builtins.py:1295
 msgid ""
 "Create a stacked branch that references the public location of the parent "
 "branch."
 msgstr ""
 
 # help of 'stacked-on' option of 'push' command
-#: bzrlib/builtins.py:1307
+#: bzrlib/builtins.py:1298
 msgid ""
 "Create a stacked branch that refers to another branch for the commit "
 "history. Only the work not present in the referenced branch is included in "
@@ -620,48 +620,42 @@
 
 # help of 'strict' option of 'dpush' command
 # help of 'strict' option of 'push' command
-#: bzrlib/builtins.py:1312 bzrlib/foreign.py:279
+#: bzrlib/builtins.py:1303 bzrlib/foreign.py:279
 msgid ""
 "Refuse to push if there are uncommitted changes in the working tree, --no-"
 "strict disables the check."
 msgstr ""
 
 # help of 'no-tree' option of 'push' command
-#: bzrlib/builtins.py:1315
+#: bzrlib/builtins.py:1306
 msgid "Don't populate the working tree, even for protocols that support it."
 msgstr ""
 
-# help of 'overwrite-tags' option of 'pull' command
-# help of 'overwrite-tags' option of 'push' command
-#: bzrlib/builtins.py:1318
-msgid "Overwrite tags only."
-msgstr ""
-
-#: bzrlib/builtins.py:1369
+#: bzrlib/builtins.py:1350
 msgid "Could not determine branch to refer to."
 msgstr ""
 
-#: bzrlib/builtins.py:1378
+#: bzrlib/builtins.py:1359
 #, python-format
 msgid ""
 "No push location known or specified. To push to the parent branch (at %s), "
 "use 'bzr push :parent'."
 msgstr ""
 
-#: bzrlib/builtins.py:1384 bzrlib/foreign.py:306
+#: bzrlib/builtins.py:1365 bzrlib/foreign.py:306
 msgid "No push location known or specified."
 msgstr ""
 
-#: bzrlib/builtins.py:1388
+#: bzrlib/builtins.py:1369
 #, python-format
 msgid "Using saved push location: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:1398
+#: bzrlib/builtins.py:1379
 msgid "Create a new branch that is a copy of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1400
+#: bzrlib/builtins.py:1381
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the FROM_LOCATION will\n"
 "be used.  In other words, \"branch ../foo/bar\" will attempt to create ./"
@@ -672,112 +666,112 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1407
+#: bzrlib/builtins.py:1388
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"branch foo/bar -r 5\"."
 msgstr ""
 
-#: bzrlib/builtins.py:1410
+#: bzrlib/builtins.py:1391
 msgid "The synonyms 'clone' and 'get' for this command are deprecated."
 msgstr ""
 
 # help of 'no-tree' option of 'branch' command
-#: bzrlib/builtins.py:1420
+#: bzrlib/builtins.py:1401
 msgid "Create a branch without a working-tree."
 msgstr ""
 
 # help of 'switch' option of 'branch' command
-#: bzrlib/builtins.py:1422
+#: bzrlib/builtins.py:1403
 msgid "Switch the checkout in the current directory to the new branch."
 msgstr ""
 
 # help of 'stacked' option of 'branch' command
-#: bzrlib/builtins.py:1425
+#: bzrlib/builtins.py:1406
 msgid ""
 "Create a stacked branch referring to the source branch. The new branch will "
 "depend on the availability of the source branch for all operations."
 msgstr ""
 
 # help of 'standalone' option of 'branch' command
-#: bzrlib/builtins.py:1429
+#: bzrlib/builtins.py:1410
 msgid "Do not use a shared repository, even if available."
 msgstr ""
 
 # help of 'use-existing-dir' option of 'branch' command
-#: bzrlib/builtins.py:1431
+#: bzrlib/builtins.py:1412
 msgid ""
 "By default branch will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow branch to proceed."
 msgstr ""
 
 # help of 'bind' option of 'branch' command
-#: bzrlib/builtins.py:1436
+#: bzrlib/builtins.py:1417
 msgid "Bind new branch to from location."
 msgstr ""
 
-#: bzrlib/builtins.py:1483
+#: bzrlib/builtins.py:1464
 #, python-format
 msgid "Target directory \"%s\" already exists."
 msgstr ""
 
+#: bzrlib/builtins.py:1476
+#, python-format
+msgid "Parent of \"%s\" does not exist."
+msgstr ""
+
 #: bzrlib/builtins.py:1495
-#, python-format
-msgid "Parent of \"%s\" does not exist."
-msgstr ""
-
-#: bzrlib/builtins.py:1514
 msgid "The branch {0} has no revision {1}."
 msgstr ""
 
-#: bzrlib/builtins.py:1529 bzrlib/push.py:53
+#: bzrlib/builtins.py:1510 bzrlib/push.py:53
 #, python-format
 msgid "Created new stacked branch referring to %s."
 msgstr ""
 
-#: bzrlib/builtins.py:1533
+#: bzrlib/builtins.py:1514
 #, python-format
 msgid "Branched %d revision."
 msgid_plural "Branched %d revisions."
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:1538
+#: bzrlib/builtins.py:1519
 #, python-format
 msgid "New branch bound to %s"
 msgstr ""
 
-#: bzrlib/builtins.py:1543 bzrlib/builtins.py:6280
+#: bzrlib/builtins.py:1524 bzrlib/builtins.py:6247
 #, python-format
 msgid "Switched to branch: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:1548
+#: bzrlib/builtins.py:1529
 msgid "List the branches available at the current location."
 msgstr ""
 
-#: bzrlib/builtins.py:1550
+#: bzrlib/builtins.py:1531
 msgid ""
 "This command will print the names of all the branches at the current\n"
 "location."
 msgstr ""
 
 # help of 'recursive' option of 'branches' command
-#: bzrlib/builtins.py:1557
+#: bzrlib/builtins.py:1538
 msgid ""
 "Recursively scan for branches rather than just looking in the specified "
 "location."
 msgstr ""
 
-#: bzrlib/builtins.py:1586
+#: bzrlib/builtins.py:1567
 msgid "(default)"
 msgstr ""
 
-#: bzrlib/builtins.py:1598
+#: bzrlib/builtins.py:1579
 msgid "Create a new checkout of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1600
+#: bzrlib/builtins.py:1581
 msgid ""
 "If BRANCH_LOCATION is omitted, checkout will reconstitute a working tree "
 "for\n"
@@ -787,7 +781,7 @@
 "location using SFTP."
 msgstr ""
 
-#: bzrlib/builtins.py:1605
+#: bzrlib/builtins.py:1586
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the BRANCH_LOCATION "
 "will\n"
@@ -799,7 +793,7 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1612
+#: bzrlib/builtins.py:1593
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"checkout foo/bar -r 5\". Note that this will be "
@@ -810,7 +804,7 @@
 msgstr ""
 
 # help of 'lightweight' option of 'checkout' command
-#: bzrlib/builtins.py:1622
+#: bzrlib/builtins.py:1603
 msgid ""
 "Perform a lightweight checkout.  Lightweight checkouts depend on access to "
 "the branch for every operation.  Normal checkouts can perform common "
@@ -820,40 +814,40 @@
 
 # help of 'files-from' option of 'branch' command
 # help of 'files-from' option of 'checkout' command
-#: bzrlib/builtins.py:1629
+#: bzrlib/builtins.py:1610
 msgid "Get file contents from this tree."
 msgstr ""
 
 # help of 'hardlink' option of 'branch' command
 # help of 'hardlink' option of 'checkout' command
-#: bzrlib/builtins.py:1631
+#: bzrlib/builtins.py:1612
 msgid "Hard-link working tree files where possible."
 msgstr ""
 
-#: bzrlib/builtins.py:1672
+#: bzrlib/builtins.py:1653
 msgid ""
 "Show list of renamed files.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:1700
+#: bzrlib/builtins.py:1681
 msgid "Update a working tree to a new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:1702
+#: bzrlib/builtins.py:1683
 msgid ""
 "This will perform a merge of the destination revision (the tip of the\n"
 "branch, or the specified revision) into the working tree, and then make\n"
 "that revision the basis revision for the working tree.  "
 msgstr ""
 
-#: bzrlib/builtins.py:1706
+#: bzrlib/builtins.py:1687
 msgid ""
 "You can use this to visit an older revision, or to update a working tree\n"
 "that is out of date from its branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1709
+#: bzrlib/builtins.py:1690
 msgid ""
 "If there are any uncommitted changes in the tree, they will be carried\n"
 "across and remain as uncommitted changes after the update.  To discard\n"
@@ -861,13 +855,13 @@
 "with the changes brought in by the change in basis revision."
 msgstr ""
 
-#: bzrlib/builtins.py:1714
+#: bzrlib/builtins.py:1695
 msgid ""
 "If the tree's branch is bound to a master branch, bzr will also update\n"
 "the branch from the master."
 msgstr ""
 
-#: bzrlib/builtins.py:1717
+#: bzrlib/builtins.py:1698
 msgid ""
 "You cannot update just a single file or directory, because each Bazaar\n"
 "working tree has just a single basis revision.  If you want to restore a\n"
@@ -877,158 +871,158 @@
 "out the old content of that file to a new location."
 msgstr ""
 
-#: bzrlib/builtins.py:1724
+#: bzrlib/builtins.py:1705
 msgid ""
 "The 'dir' argument, if given, must be the location of the root of a\n"
 "working tree to update.  By default, the working tree that contains the \n"
 "current working directory is used."
 msgstr ""
 
-#: bzrlib/builtins.py:1740
+#: bzrlib/builtins.py:1721
 msgid "bzr update --revision takes exactly one revision"
 msgstr ""
 
-#: bzrlib/builtins.py:1748
+#: bzrlib/builtins.py:1729
 msgid "bzr update can only update a whole tree, not a file or subdirectory"
 msgstr ""
 
-#: bzrlib/builtins.py:1779
+#: bzrlib/builtins.py:1760
 msgid "Tree is up to date at revision {0} of branch {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:1795
+#: bzrlib/builtins.py:1776
 #, python-format
 msgid ""
 "branch has no revision %s\n"
 "bzr update --revision only works for a revision in the branch history"
 msgstr ""
 
-#: bzrlib/builtins.py:1801
+#: bzrlib/builtins.py:1782
 msgid "Updated to revision {0} of branch {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:1805
+#: bzrlib/builtins.py:1786
 msgid ""
 "Your local commits will now show as pending merges with 'bzr status', and "
 "can be committed with 'bzr commit'."
 msgstr ""
 
-#: bzrlib/builtins.py:1814
+#: bzrlib/builtins.py:1795
 msgid "Show information about a working tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1816
+#: bzrlib/builtins.py:1797
 msgid ""
 "This command will show all known locations and formats associated to the\n"
 "tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1819
+#: bzrlib/builtins.py:1800
 msgid ""
 "In verbose mode, statistical information is included with each report.\n"
 "To see extended statistic information, use a verbosity level of 2 or\n"
 "higher by specifying the verbose option multiple times, e.g. -vv."
 msgstr ""
 
-#: bzrlib/builtins.py:1823
+#: bzrlib/builtins.py:1804
 msgid "Branches and working trees will also report any missing revisions."
 msgstr ""
 
-#: bzrlib/builtins.py:1825 bzrlib/builtins.py:3744 bzrlib/builtins.py:4885
-#: bzrlib/builtins.py:6466
+#: bzrlib/builtins.py:1806 bzrlib/builtins.py:3725 bzrlib/builtins.py:4859
+#: bzrlib/builtins.py:6433
 msgid ":Examples:"
 msgstr ""
 
-#: bzrlib/builtins.py:1827
+#: bzrlib/builtins.py:1808
 msgid "  Display information on the format and related locations:"
 msgstr ""
 
-#: bzrlib/builtins.py:1829
+#: bzrlib/builtins.py:1810
 msgid "    bzr info"
 msgstr ""
 
-#: bzrlib/builtins.py:1831
+#: bzrlib/builtins.py:1812
 msgid ""
 "  Display the above together with extended format information and\n"
 "  basic statistics (like the number of files in the working tree and\n"
 "  number of revisions in the branch and repository):"
 msgstr ""
 
-#: bzrlib/builtins.py:1835
+#: bzrlib/builtins.py:1816
 msgid "    bzr info -v"
 msgstr ""
 
-#: bzrlib/builtins.py:1837
+#: bzrlib/builtins.py:1818
 msgid "  Display the above together with number of committers to the branch:"
 msgstr ""
 
+#: bzrlib/builtins.py:1820
+msgid "    bzr info -vv"
+msgstr ""
+
 #: bzrlib/builtins.py:1839
-msgid "    bzr info -vv"
-msgstr ""
-
-#: bzrlib/builtins.py:1858
 msgid "Remove files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:1860
+#: bzrlib/builtins.py:1841
 msgid ""
 "This makes Bazaar stop tracking changes to the specified files. Bazaar will\n"
 "delete them if they can easily be recovered using revert otherwise they\n"
-"will be backed up (adding an extension of the form .~#~). If no options or\n"
+"will be backed up (adding an extention of the form .~#~). If no options or\n"
 "parameters are given Bazaar will scan for files that are being tracked by\n"
 "Bazaar but missing in your tree and stop tracking them for you."
 msgstr ""
 
 # help of 'new' option of 'remove' command
-#: bzrlib/builtins.py:1868
+#: bzrlib/builtins.py:1849
 msgid "Only remove files that have never been committed."
 msgstr ""
 
 # help of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1870
+#: bzrlib/builtins.py:1851
 msgid "The file deletion mode to be used."
 msgstr ""
 
 # title of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1871
+#: bzrlib/builtins.py:1852
 msgid "Deletion Strategy"
 msgstr ""
 
 # help of 'file-deletion-strategy=safe' option of 'remove' command
-#: bzrlib/builtins.py:1872
+#: bzrlib/builtins.py:1853
 msgid "Backup changed files (default)."
 msgstr ""
 
 # help of 'file-deletion-strategy=keep' option of 'remove' command
-#: bzrlib/builtins.py:1873
+#: bzrlib/builtins.py:1854
 msgid "Delete from bzr but leave the working copy."
 msgstr ""
 
 # help of 'file-deletion-strategy=no-backup' option of 'remove' command
-#: bzrlib/builtins.py:1874
+#: bzrlib/builtins.py:1855
 msgid "Don't backup changed files."
 msgstr ""
 
 # help of 'file-deletion-strategy=force' option of 'remove' command
-#: bzrlib/builtins.py:1875
+#: bzrlib/builtins.py:1856
 msgid ""
 "Delete all the specified files, even if they can not be recovered and even "
 "if they are non-empty directories. (deprecated, use no-backup)"
 msgstr ""
 
-#: bzrlib/builtins.py:1884
+#: bzrlib/builtins.py:1865
 msgid "(The --force option is deprecated, rather use --no-backup in future.)"
 msgstr ""
 
-#: bzrlib/builtins.py:1901
+#: bzrlib/builtins.py:1882
 msgid "No matching files."
 msgstr ""
 
-#: bzrlib/builtins.py:1962
+#: bzrlib/builtins.py:1943
 msgid "Reconcile bzr metadata in a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1964
+#: bzrlib/builtins.py:1945
 msgid ""
 "This can correct data mismatches that may have been caused by\n"
 "previous ghost operations or bzr upgrades. You should only\n"
@@ -1036,7 +1030,7 @@
 "advises you to run it."
 msgstr ""
 
-#: bzrlib/builtins.py:1969
+#: bzrlib/builtins.py:1950
 msgid ""
 "If a second branch is provided, cross-branch reconciliation is\n"
 "also attempted, which will check that data like the tree root\n"
@@ -1044,13 +1038,13 @@
 "correctly in both branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1974
+#: bzrlib/builtins.py:1955
 msgid ""
 "At the same time it is run it may recompress data resulting in\n"
 "a potential saving in disk space or performance gain."
 msgstr ""
 
-#: bzrlib/builtins.py:1977
+#: bzrlib/builtins.py:1958
 msgid "The branch *MUST* be on a listable system such as local disk or sftp."
 msgstr ""
 
@@ -1060,7 +1054,7 @@
 # help of 'format=default' option of 'init-repository' command
 # help of 'format=2a' option of 'upgrade' command
 # help of 'format=default' option of 'upgrade' command
-#: bzrlib/builtins.py:2044 bzrlib/builtins.py:2162 bzrlib/builtins.py:3779
+#: bzrlib/builtins.py:2025 bzrlib/builtins.py:2143 bzrlib/builtins.py:3760
 msgid ""
 "Format for the bzr 2.0 series.\n"
 "Uses group-compress storage.\n"
@@ -1070,7 +1064,7 @@
 # help of 'format=pack-0.92' option of 'init' command
 # help of 'format=pack-0.92' option of 'init-repository' command
 # help of 'format=pack-0.92' option of 'upgrade' command
-#: bzrlib/builtins.py:2044 bzrlib/builtins.py:2162 bzrlib/builtins.py:3779
+#: bzrlib/builtins.py:2025 bzrlib/builtins.py:2143 bzrlib/builtins.py:3760
 msgid ""
 "Pack-based format used in 1.x series. Introduced in 0.92. Interoperates with "
 "bzr repositories before 0.92 but cannot be read by bzr < 0.92. "
@@ -1079,21 +1073,21 @@
 # help of 'format=development-colo' option of 'init' command
 # help of 'format=development-colo' option of 'init-repository' command
 # help of 'format=development-colo' option of 'upgrade' command
-#: bzrlib/builtins.py:2044 bzrlib/builtins.py:2162 bzrlib/builtins.py:3779
+#: bzrlib/builtins.py:2025 bzrlib/builtins.py:2143 bzrlib/builtins.py:3760
 msgid "The 2a format with experimental support for colocated branches.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:2045
+#: bzrlib/builtins.py:2026
 msgid "Make a directory into a versioned branch."
 msgstr ""
 
-#: bzrlib/builtins.py:2047
+#: bzrlib/builtins.py:2028
 msgid ""
 "Use this to create an empty branch, or before importing an\n"
 "existing project."
 msgstr ""
 
-#: bzrlib/builtins.py:2050
+#: bzrlib/builtins.py:2031
 msgid ""
 "If there is a repository in a parent directory of the location, then\n"
 "the history of the branch will be stored in the repository.  Otherwise\n"
@@ -1101,17 +1095,17 @@
 "in the .bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2055
+#: bzrlib/builtins.py:2036
 msgid ""
 "If there is already a branch at the location but it has no working tree,\n"
 "the tree can be populated with 'bzr checkout'."
 msgstr ""
 
-#: bzrlib/builtins.py:2058
+#: bzrlib/builtins.py:2039
 msgid "Recipe for importing a tree of files::"
 msgstr ""
 
-#: bzrlib/builtins.py:2060
+#: bzrlib/builtins.py:2041
 msgid ""
 "    cd ~/project\n"
 "    bzr init\n"
@@ -1122,51 +1116,51 @@
 
 # help of 'create-prefix' option of 'init' command
 # help of 'create-prefix' option of 'push' command
-#: bzrlib/builtins.py:2071
+#: bzrlib/builtins.py:2052
 msgid "Create the path leading up to the branch if it does not already exist."
 msgstr ""
 
 # help of 'format' option of 'init' command
-#: bzrlib/builtins.py:2074
+#: bzrlib/builtins.py:2055
 msgid "Specify a format for this branch. See \"help formats\"."
 msgstr ""
 
 # help of 'append-revisions-only' option of 'init' command
-#: bzrlib/builtins.py:2082
+#: bzrlib/builtins.py:2063
 msgid "Never change revnos or the existing log.  Append revisions to it only."
 msgstr ""
 
 # help of 'no-tree' option of 'init' command
-#: bzrlib/builtins.py:2085
+#: bzrlib/builtins.py:2066
 msgid "Create a branch without a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:2105 bzrlib/push.py:110
+#: bzrlib/builtins.py:2086 bzrlib/push.py:110
 #, python-format
 msgid ""
 "Parent directory of %s does not exist.\n"
 "You may supply --create-prefix to create all leading parent directories."
 msgstr ""
 
-#: bzrlib/builtins.py:2139
+#: bzrlib/builtins.py:2120
 msgid ""
 "This branch format cannot be set to append-revisions-only.  Try --default."
 msgstr ""
 
-#: bzrlib/builtins.py:2150
+#: bzrlib/builtins.py:2131
 msgid "Created a {0} (format: {1})\n"
 msgstr ""
 
-#: bzrlib/builtins.py:2159
+#: bzrlib/builtins.py:2140
 #, python-format
 msgid "Using shared repository: %s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:2163
+#: bzrlib/builtins.py:2144
 msgid "Create a shared repository for branches to share storage space."
 msgstr ""
 
-#: bzrlib/builtins.py:2165
+#: bzrlib/builtins.py:2146
 msgid ""
 "New branches created under the repository directory will store their\n"
 "revisions in the repository, not in the branch directory.  For branches\n"
@@ -1174,7 +1168,7 @@
 "speeds up the creation of new branches."
 msgstr ""
 
-#: bzrlib/builtins.py:2170
+#: bzrlib/builtins.py:2151
 msgid ""
 "If the --no-trees option is given then the branches in the repository\n"
 "will not have working trees by default.  They will still exist as \n"
@@ -1184,23 +1178,23 @@
 "branches, such as on a server."
 msgstr ""
 
-#: bzrlib/builtins.py:2177
+#: bzrlib/builtins.py:2158
 msgid ""
 ":Examples:\n"
 "    Create a shared repository holding just branches::"
 msgstr ""
 
-#: bzrlib/builtins.py:2180
+#: bzrlib/builtins.py:2161
 msgid ""
 "        bzr init-repo --no-trees repo\n"
 "        bzr init repo/trunk"
 msgstr ""
 
-#: bzrlib/builtins.py:2183
+#: bzrlib/builtins.py:2164
 msgid "    Make a lightweight checkout elsewhere::"
 msgstr ""
 
-#: bzrlib/builtins.py:2185
+#: bzrlib/builtins.py:2166
 msgid ""
 "        bzr checkout --lightweight repo/trunk trunk-checkout\n"
 "        cd trunk-checkout\n"
@@ -1208,26 +1202,26 @@
 msgstr ""
 
 # help of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:2193
+#: bzrlib/builtins.py:2174
 msgid ""
 "Specify a format for this repository. See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:2197
+#: bzrlib/builtins.py:2178
 msgid "Repository format"
 msgstr ""
 
 # help of 'no-trees' option of 'init-repository' command
-#: bzrlib/builtins.py:2199
+#: bzrlib/builtins.py:2180
 msgid "Branches in the repository will default to not having a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:2225
+#: bzrlib/builtins.py:2206
 msgid "Show differences in the working tree, between revisions or branches."
 msgstr ""
 
-#: bzrlib/builtins.py:2227
+#: bzrlib/builtins.py:2208
 msgid ""
 "If no arguments are given, all changes for the current tree are listed.\n"
 "If files are given, only the changes in those files are listed.\n"
@@ -1237,13 +1231,13 @@
 "given."
 msgstr ""
 
-#: bzrlib/builtins.py:2234
+#: bzrlib/builtins.py:2215
 msgid ""
 "\"bzr diff -p1\" is equivalent to \"bzr diff --prefix old/:new/\", and\n"
 "produces patches suitable for \"patch -p1\"."
 msgstr ""
 
-#: bzrlib/builtins.py:2237
+#: bzrlib/builtins.py:2218
 msgid ""
 "Note that when using the -r argument with a range of revisions, the\n"
 "differences are computed between the two specified revisions.  That\n"
@@ -1253,7 +1247,7 @@
 "in the range."
 msgstr ""
 
-#: bzrlib/builtins.py:2244
+#: bzrlib/builtins.py:2225
 msgid ""
 ":Exit values:\n"
 "    1 - changed\n"
@@ -1262,113 +1256,113 @@
 "    0 - no change"
 msgstr ""
 
-#: bzrlib/builtins.py:2250
+#: bzrlib/builtins.py:2231
 msgid ""
 ":Examples:\n"
 "    Shows the difference in the working tree versus the last commit::"
 msgstr ""
 
-#: bzrlib/builtins.py:2253
+#: bzrlib/builtins.py:2234
 msgid "        bzr diff"
 msgstr ""
 
-#: bzrlib/builtins.py:2255
+#: bzrlib/builtins.py:2236
 msgid "    Difference between the working tree and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:2257
+#: bzrlib/builtins.py:2238
 msgid "        bzr diff -r1"
 msgstr ""
 
-#: bzrlib/builtins.py:2259
+#: bzrlib/builtins.py:2240
 msgid "    Difference between revision 3 and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:2261
+#: bzrlib/builtins.py:2242
 msgid "        bzr diff -r1..3"
 msgstr ""
 
-#: bzrlib/builtins.py:2263
+#: bzrlib/builtins.py:2244
 msgid "    Difference between revision 3 and revision 1 for branch xxx::"
 msgstr ""
 
-#: bzrlib/builtins.py:2265
+#: bzrlib/builtins.py:2246
 msgid "        bzr diff -r1..3 xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2267
+#: bzrlib/builtins.py:2248
 msgid "    The changes introduced by revision 2 (equivalent to -r1..2)::"
 msgstr ""
 
-#: bzrlib/builtins.py:2269
+#: bzrlib/builtins.py:2250
 msgid "        bzr diff -c2"
 msgstr ""
 
-#: bzrlib/builtins.py:2271
+#: bzrlib/builtins.py:2252
 msgid ""
 "    To see the changes introduced by revision X::\n"
 "    \n"
 "        bzr diff -cX"
 msgstr ""
 
-#: bzrlib/builtins.py:2275
+#: bzrlib/builtins.py:2256
 msgid ""
 "    Note that in the case of a merge, the -c option shows the changes\n"
 "    compared to the left hand parent. To see the changes against\n"
 "    another parent, use::"
 msgstr ""
 
-#: bzrlib/builtins.py:2279
+#: bzrlib/builtins.py:2260
 msgid "        bzr diff -r<chosen_parent>..X"
 msgstr ""
 
-#: bzrlib/builtins.py:2281
+#: bzrlib/builtins.py:2262
 msgid ""
 "    The changes between the current revision and the previous revision\n"
 "    (equivalent to -c-1 and -r-2..-1)"
 msgstr ""
 
-#: bzrlib/builtins.py:2284
+#: bzrlib/builtins.py:2265
 msgid "        bzr diff -r-2.."
 msgstr ""
 
-#: bzrlib/builtins.py:2286
+#: bzrlib/builtins.py:2267
 msgid "    Show just the differences for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2288
+#: bzrlib/builtins.py:2269
 msgid "        bzr diff NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2290
+#: bzrlib/builtins.py:2271
 msgid "    Show the differences in working tree xxx for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2292
+#: bzrlib/builtins.py:2273
 msgid "        bzr diff xxx/NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2294
+#: bzrlib/builtins.py:2275
 msgid "    Show the differences from branch xxx to this working tree:"
 msgstr ""
 
-#: bzrlib/builtins.py:2296
+#: bzrlib/builtins.py:2277
 msgid "        bzr diff --old xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2298
+#: bzrlib/builtins.py:2279
 msgid "    Show the differences between two branches for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2300
+#: bzrlib/builtins.py:2281
 msgid "        bzr diff --old xxx --new yyy NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2302
+#: bzrlib/builtins.py:2283
 msgid "    Same as 'bzr diff' but prefix paths with old/ and new/::"
 msgstr ""
 
-#: bzrlib/builtins.py:2304
+#: bzrlib/builtins.py:2285
 msgid ""
 "        bzr diff --prefix old/:new/\n"
 "        \n"
@@ -1378,84 +1372,84 @@
 msgstr ""
 
 # help of 'diff-options' option of 'diff' command
-#: bzrlib/builtins.py:2314
+#: bzrlib/builtins.py:2295
 msgid "Pass these options to the external diff program."
 msgstr ""
 
 # help of 'prefix' option of 'diff' command
-#: bzrlib/builtins.py:2317
+#: bzrlib/builtins.py:2298
 msgid ""
 "Set prefixes added to old and new filenames, as two values separated by a "
 "colon. (eg \"old/:new/\")."
 msgstr ""
 
 # help of 'old' option of 'diff' command
-#: bzrlib/builtins.py:2320
+#: bzrlib/builtins.py:2301
 msgid "Branch/tree to compare from."
 msgstr ""
 
 # help of 'new' option of 'diff' command
-#: bzrlib/builtins.py:2324
+#: bzrlib/builtins.py:2305
 msgid "Branch/tree to compare to."
 msgstr ""
 
 # help of 'using' option of 'diff' command
-#: bzrlib/builtins.py:2330
+#: bzrlib/builtins.py:2311
 msgid "Use this command to compare files."
 msgstr ""
 
 # help of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2335
+#: bzrlib/builtins.py:2316
 msgid "Diff format to use."
 msgstr ""
 
 # title of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2337
+#: bzrlib/builtins.py:2318
 msgid "Diff format"
 msgstr ""
 
-#: bzrlib/builtins.py:2359
+#: bzrlib/builtins.py:2340
 msgid "--prefix expects two values separated by a colon (eg \"old/:new/\")"
 msgstr ""
 
-#: bzrlib/builtins.py:2363
+#: bzrlib/builtins.py:2344
 msgid "bzr diff --revision takes exactly one or two revision specifiers"
 msgstr ""
 
-#: bzrlib/builtins.py:2368 bzrlib/builtins.py:2765 bzrlib/builtins.py:2778
-#: bzrlib/builtins.py:2786 bzrlib/builtins.py:4959
+#: bzrlib/builtins.py:2349 bzrlib/builtins.py:2746 bzrlib/builtins.py:2759
+#: bzrlib/builtins.py:2767 bzrlib/builtins.py:4933
 msgid "{0} and {1} are mutually exclusive"
 msgstr ""
 
-#: bzrlib/builtins.py:2388
+#: bzrlib/builtins.py:2369
 msgid ""
 "List files deleted in the working tree.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:2465
+#: bzrlib/builtins.py:2446
 msgid "Show the tree root directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2467
+#: bzrlib/builtins.py:2448
 msgid ""
 "The root is the nearest enclosing directory with a .bzr control\n"
 "directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2482
+#: bzrlib/builtins.py:2463
 msgid "The limit argument must be an integer."
 msgstr ""
 
-#: bzrlib/builtins.py:2490
+#: bzrlib/builtins.py:2471
 msgid "The levels argument must be an integer."
 msgstr ""
 
-#: bzrlib/builtins.py:2495
+#: bzrlib/builtins.py:2476
 msgid "Show historical log for a branch or subset of a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:2497
+#: bzrlib/builtins.py:2478
 msgid ""
 "log is bzr's default tool for exploring the history of a branch.\n"
 "The branch to use is taken from the first parameter. If no parameters\n"
@@ -1463,14 +1457,14 @@
 "Here are some simple examples::"
 msgstr ""
 
-#: bzrlib/builtins.py:2502
+#: bzrlib/builtins.py:2483
 msgid ""
 "  bzr log                       log the current branch\n"
 "  bzr log foo.py                log a file in its branch\n"
 "  bzr log http://server/branch  log a branch on a server"
 msgstr ""
 
-#: bzrlib/builtins.py:2506
+#: bzrlib/builtins.py:2487
 msgid ""
 "The filtering, ordering and information shown for each revision can\n"
 "be controlled as explained below. By default, all revisions are\n"
@@ -1480,11 +1474,11 @@
 "were merged."
 msgstr ""
 
-#: bzrlib/builtins.py:2513
+#: bzrlib/builtins.py:2494
 msgid ":Output control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2515
+#: bzrlib/builtins.py:2496
 msgid ""
 "  The log format controls how information about each revision is\n"
 "  displayed. The standard log formats are called ``long``, ``short``\n"
@@ -1492,13 +1486,13 @@
 "  for more details on log formats."
 msgstr ""
 
-#: bzrlib/builtins.py:2520
+#: bzrlib/builtins.py:2501
 msgid ""
 "  The following options can be used to control what information is\n"
 "  displayed::"
 msgstr ""
 
-#: bzrlib/builtins.py:2523
+#: bzrlib/builtins.py:2504
 msgid ""
 "    -l N        display a maximum of N revisions\n"
 "    -n N        display N levels of revisions (0 for all, 1 for collapsed)\n"
@@ -1507,25 +1501,25 @@
 "    --show-ids  display revision-ids (and file-ids), not just revnos"
 msgstr ""
 
-#: bzrlib/builtins.py:2529
+#: bzrlib/builtins.py:2510
 msgid ""
 "  Note that the default number of levels to display is a function of the\n"
 "  log format. If the -n option is not used, the standard log formats show\n"
 "  just the top level (mainline)."
 msgstr ""
 
-#: bzrlib/builtins.py:2533
+#: bzrlib/builtins.py:2514
 msgid ""
 "  Status summaries are shown using status flags like A, M, etc. To see\n"
 "  the changes explained using words like ``added`` and ``modified``\n"
 "  instead, use the -vv option."
 msgstr ""
 
-#: bzrlib/builtins.py:2537
+#: bzrlib/builtins.py:2518
 msgid ":Ordering control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2539
+#: bzrlib/builtins.py:2520
 msgid ""
 "  To display revisions from oldest to newest, use the --forward option.\n"
 "  In most cases, using this option will have little impact on the total\n"
@@ -1533,17 +1527,17 @@
 "  display revisions like --reverse does when it can."
 msgstr ""
 
-#: bzrlib/builtins.py:2544
+#: bzrlib/builtins.py:2525
 msgid ":Revision filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2546
+#: bzrlib/builtins.py:2527
 msgid ""
 "  The -r option can be used to specify what revision or range of revisions\n"
 "  to filter against. The various forms are shown below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2549
+#: bzrlib/builtins.py:2530
 msgid ""
 "    -rX      display revision X\n"
 "    -rX..    display revision X and later\n"
@@ -1551,13 +1545,13 @@
 "    -rX..Y   display from X to Y inclusive"
 msgstr ""
 
-#: bzrlib/builtins.py:2554
+#: bzrlib/builtins.py:2535
 msgid ""
 "  See ``bzr help revisionspec`` for details on how to specify X and Y.\n"
 "  Some common examples are given below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2557
+#: bzrlib/builtins.py:2538
 msgid ""
 "    -r-1                show just the tip\n"
 "    -r-10..             show the last 10 mainline revisions\n"
@@ -1567,7 +1561,7 @@
 "    -rdate:yesterday..  show changes since yesterday"
 msgstr ""
 
-#: bzrlib/builtins.py:2564
+#: bzrlib/builtins.py:2545
 msgid ""
 "  When logging a range of revisions using -rX..Y, log starts at\n"
 "  revision Y and searches back in history through the primary\n"
@@ -1577,73 +1571,73 @@
 "  a nested merge revision and the log will be truncated accordingly."
 msgstr ""
 
-#: bzrlib/builtins.py:2571
+#: bzrlib/builtins.py:2552
 msgid ":Path filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2573
+#: bzrlib/builtins.py:2554
 msgid ""
 "  If parameters are given and the first one is not a branch, the log\n"
 "  will be filtered to show only those revisions that changed the\n"
 "  nominated files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:2577
+#: bzrlib/builtins.py:2558
 msgid ""
 "  Filenames are interpreted within their historical context. To log a\n"
 "  deleted file, specify a revision range so that the file existed at\n"
 "  the end or start of the range."
 msgstr ""
 
-#: bzrlib/builtins.py:2581
+#: bzrlib/builtins.py:2562
 msgid ""
 "  Historical context is also important when interpreting pathnames of\n"
 "  renamed files/directories. Consider the following example:"
 msgstr ""
 
-#: bzrlib/builtins.py:2584
+#: bzrlib/builtins.py:2565
 msgid ""
 "  * revision 1: add tutorial.txt\n"
 "  * revision 2: modify tutorial.txt\n"
 "  * revision 3: rename tutorial.txt to guide.txt; add tutorial.txt"
 msgstr ""
 
-#: bzrlib/builtins.py:2588
+#: bzrlib/builtins.py:2569
 msgid "  In this case:"
 msgstr ""
 
-#: bzrlib/builtins.py:2590
+#: bzrlib/builtins.py:2571
 msgid "  * ``bzr log guide.txt`` will log the file added in revision 1"
 msgstr ""
 
-#: bzrlib/builtins.py:2592
+#: bzrlib/builtins.py:2573
 msgid "  * ``bzr log tutorial.txt`` will log the new file added in revision 3"
 msgstr ""
 
-#: bzrlib/builtins.py:2594
+#: bzrlib/builtins.py:2575
 msgid ""
 "  * ``bzr log -r2 -p tutorial.txt`` will show the changes made to\n"
 "    the original file in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2597
+#: bzrlib/builtins.py:2578
 msgid ""
 "  * ``bzr log -r2 -p guide.txt`` will display an error message as there\n"
 "    was no file called guide.txt in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2600
+#: bzrlib/builtins.py:2581
 msgid ""
 "  Renames are always followed by log. By design, there is no need to\n"
 "  explicitly ask for this (and no way to stop logging a file back\n"
 "  until it was last renamed)."
 msgstr ""
 
-#: bzrlib/builtins.py:2604
+#: bzrlib/builtins.py:2585
 msgid ":Other filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2606
+#: bzrlib/builtins.py:2587
 msgid ""
 "  The --match option can be used for finding revisions that match a\n"
 "  regular expression in a commit message, committer, author or bug.\n"
@@ -1652,11 +1646,11 @@
 "  --match-message can be used to only match a specific field."
 msgstr ""
 
-#: bzrlib/builtins.py:2612
+#: bzrlib/builtins.py:2593
 msgid ":Tips & tricks:"
 msgstr ""
 
-#: bzrlib/builtins.py:2614
+#: bzrlib/builtins.py:2595
 msgid ""
 "  GUI tools and IDEs are often better at exploring history than command\n"
 "  line tools: you may prefer qlog or viz from qbzr or bzr-gtk, the\n"
@@ -1665,11 +1659,11 @@
 "  <http://wiki.bazaar.canonical.com/IDEIntegration>.  "
 msgstr ""
 
-#: bzrlib/builtins.py:2620
+#: bzrlib/builtins.py:2601
 msgid "  You may find it useful to add the aliases below to ``bazaar.conf``::"
 msgstr ""
 
-#: bzrlib/builtins.py:2622
+#: bzrlib/builtins.py:2603
 msgid ""
 "    [ALIASES]\n"
 "    tip = log -r-1\n"
@@ -1677,20 +1671,20 @@
 "    show = log -v -p"
 msgstr ""
 
-#: bzrlib/builtins.py:2627
+#: bzrlib/builtins.py:2608
 msgid ""
 "  ``bzr tip`` will then show the latest revision while ``bzr top``\n"
 "  will show the last 10 mainline revisions. To see the details of a\n"
 "  particular revision X,  ``bzr show -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2631
+#: bzrlib/builtins.py:2612
 msgid ""
 "  If you are interested in looking deeper into a particular merge X,\n"
 "  use ``bzr log -n0 -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2634
+#: bzrlib/builtins.py:2615
 msgid ""
 "  ``bzr log -v`` on a branch with lots of history is currently\n"
 "  very slow. A fix for this issue is currently under development.\n"
@@ -1698,7 +1692,7 @@
 "  be given when using the -v option."
 msgstr ""
 
-#: bzrlib/builtins.py:2639
+#: bzrlib/builtins.py:2620
 msgid ""
 "  bzr has a generic full-text matching plugin, bzr-search, that can be\n"
 "  used to find revisions matching user names, commit messages, etc.\n"
@@ -1706,7 +1700,7 @@
 "  a list of words but not others."
 msgstr ""
 
-#: bzrlib/builtins.py:2644
+#: bzrlib/builtins.py:2625
 msgid ""
 "  When exploring non-mainline history on large projects with deep\n"
 "  history, the performance of log can be greatly improved by installing\n"
@@ -1715,168 +1709,168 @@
 msgstr ""
 
 # help of 'forward' option of 'log' command
-#: bzrlib/builtins.py:2653
+#: bzrlib/builtins.py:2634
 msgid "Show from oldest to newest."
 msgstr ""
 
 # help of 'verbose' option of 'log' command
-#: bzrlib/builtins.py:2656
+#: bzrlib/builtins.py:2637
 msgid "Show files changed in each revision."
 msgstr ""
 
 # help of 'change' option of 'log' command
-#: bzrlib/builtins.py:2662
+#: bzrlib/builtins.py:2643
 msgid "Show just the specified revision. See also \"help revisionspec\"."
 msgstr ""
 
 # help of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2666
+#: bzrlib/builtins.py:2647
 msgid "What names to list as authors - first, all or committer."
 msgstr ""
 
 # title of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2667
+#: bzrlib/builtins.py:2648
 msgid "Authors"
 msgstr ""
 
 # help of 'levels' option of 'log' command
-#: bzrlib/builtins.py:2672
+#: bzrlib/builtins.py:2653
 msgid "Number of levels to display - 0 for all, 1 for flat."
 msgstr ""
 
 # help of 'limit' option of 'log' command
-#: bzrlib/builtins.py:2682
+#: bzrlib/builtins.py:2663
 msgid "Limit the output to the first N revisions."
 msgstr ""
 
 # help of 'show-diff' option of 'log' command
-#: bzrlib/builtins.py:2687
+#: bzrlib/builtins.py:2668
 msgid "Show changes made in each revision as a patch."
 msgstr ""
 
 # help of 'include-merged' option of 'log' command
-#: bzrlib/builtins.py:2689
+#: bzrlib/builtins.py:2670
 msgid "Show merged revisions like --levels 0 does."
 msgstr ""
 
 # help of 'omit-merges' option of 'log' command
-#: bzrlib/builtins.py:2693
+#: bzrlib/builtins.py:2674
 msgid "Do not report commits with more than one parent."
 msgstr ""
 
 # help of 'exclude-common-ancestry' option of 'log' command
-#: bzrlib/builtins.py:2695
+#: bzrlib/builtins.py:2676
 msgid ""
 "Display only the revisions that are not part of both ancestries (require -"
 "rX..Y)."
 msgstr ""
 
 # help of 'signatures' option of 'log' command
-#: bzrlib/builtins.py:2699
+#: bzrlib/builtins.py:2680
 msgid "Show digital signature validity."
 msgstr ""
 
 # help of 'match' option of 'log' command
-#: bzrlib/builtins.py:2702
+#: bzrlib/builtins.py:2683
 msgid "Show revisions whose properties match this expression."
 msgstr ""
 
 # help of 'match-message' option of 'log' command
-#: bzrlib/builtins.py:2706
+#: bzrlib/builtins.py:2687
 msgid "Show revisions whose message matches this expression."
 msgstr ""
 
 # help of 'match-committer' option of 'log' command
-#: bzrlib/builtins.py:2710
+#: bzrlib/builtins.py:2691
 msgid "Show revisions whose committer matches this expression."
 msgstr ""
 
 # help of 'match-author' option of 'log' command
-#: bzrlib/builtins.py:2714
+#: bzrlib/builtins.py:2695
 msgid "Show revisions whose authors match this expression."
 msgstr ""
 
 # help of 'match-bugs' option of 'log' command
-#: bzrlib/builtins.py:2718
+#: bzrlib/builtins.py:2699
 msgid "Show revisions whose bugs match this expression."
 msgstr ""
 
-#: bzrlib/builtins.py:2772
+#: bzrlib/builtins.py:2753
 msgid "--exclude-common-ancestry requires -r with two revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:2800
+#: bzrlib/builtins.py:2781
 #, python-format
 msgid "Path unknown at end or start of revision range: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:2917
+#: bzrlib/builtins.py:2898
 #, python-format
 msgid "bzr %s doesn't accept two revisions in different branches."
 msgstr ""
 
-#: bzrlib/builtins.py:2933
+#: bzrlib/builtins.py:2914
 #, python-format
 msgid "bzr %s --revision takes one or two values."
 msgstr ""
 
-#: bzrlib/builtins.py:2978
+#: bzrlib/builtins.py:2959
 msgid ""
 "List files in a tree.\n"
 "    "
 msgstr ""
 
 # help of 'recursive' option of 'ls' command
-#: bzrlib/builtins.py:2987
+#: bzrlib/builtins.py:2968
 msgid "Recurse into subdirectories."
 msgstr ""
 
 # help of 'from-root' option of 'ls' command
-#: bzrlib/builtins.py:2989
+#: bzrlib/builtins.py:2970
 msgid "Print paths relative to the root of the branch."
 msgstr ""
 
 # help of 'unknown' option of 'ls' command
-#: bzrlib/builtins.py:2991
+#: bzrlib/builtins.py:2972
 msgid "Print unknown files."
 msgstr ""
 
 # help of 'versioned' option of 'ls' command
-#: bzrlib/builtins.py:2992
+#: bzrlib/builtins.py:2973
 msgid "Print versioned files."
 msgstr ""
 
 # help of 'ignored' option of 'ls' command
-#: bzrlib/builtins.py:2995
+#: bzrlib/builtins.py:2976
 msgid "Print ignored files."
 msgstr ""
 
 # help of 'kind' option of 'ls' command
-#: bzrlib/builtins.py:2997
+#: bzrlib/builtins.py:2978
 msgid "List entries of a particular kind: file, directory, symlink."
 msgstr ""
 
-#: bzrlib/builtins.py:3010
+#: bzrlib/builtins.py:2991
 msgid "invalid kind specified"
 msgstr ""
 
-#: bzrlib/builtins.py:3013
+#: bzrlib/builtins.py:2994
 msgid "Cannot set both --verbose and --null"
 msgstr ""
 
-#: bzrlib/builtins.py:3022
+#: bzrlib/builtins.py:3003
 msgid "cannot specify both --from-root and PATH"
 msgstr ""
 
-#: bzrlib/builtins.py:3109
+#: bzrlib/builtins.py:3090
 msgid "Ignore specified files or patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:3111
+#: bzrlib/builtins.py:3092
 msgid "See ``bzr help patterns`` for details on the syntax of patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:3113
+#: bzrlib/builtins.py:3094
 msgid ""
 "If a .bzrignore file does not exist, the ignore command\n"
 "will create one and add the specified files or patterns to the newly\n"
@@ -1885,7 +1879,7 @@
 "the use of the ignore command will require an explicit add command."
 msgstr ""
 
-#: bzrlib/builtins.py:3119
+#: bzrlib/builtins.py:3100
 msgid ""
 "To remove patterns from the ignore list, edit the .bzrignore file.\n"
 "After adding, editing or deleting that file either indirectly by\n"
@@ -1893,7 +1887,7 @@
 "it."
 msgstr ""
 
-#: bzrlib/builtins.py:3124
+#: bzrlib/builtins.py:3105
 msgid ""
 "Bazaar also supports a global ignore file ~/.bazaar/ignore. On Windows\n"
 "the global ignore file can be found in the application data directory as\n"
@@ -1902,20 +1896,20 @@
 "can be edited directly using an editor."
 msgstr ""
 
-#: bzrlib/builtins.py:3130
+#: bzrlib/builtins.py:3111
 msgid ""
 "Patterns prefixed with '!' are exceptions to ignore patterns and take\n"
 "precedence over regular ignores.  Such exceptions are used to specify\n"
 "files that should be versioned which would otherwise be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:3134
+#: bzrlib/builtins.py:3115
 msgid ""
 "Patterns prefixed with '!!' act as regular ignore patterns, but have\n"
 "precedence over the '!' exception patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:3137
+#: bzrlib/builtins.py:3118
 msgid ""
 ":Notes: \n"
 "    \n"
@@ -1923,63 +1917,63 @@
 "  the shell on Unix."
 msgstr ""
 
-#: bzrlib/builtins.py:3142
+#: bzrlib/builtins.py:3123
 msgid ""
 "* Ignore patterns starting with \"#\" act as comments in the ignore file.\n"
 "  To ignore patterns that begin with that character, use the \"RE:\" prefix."
 msgstr ""
 
-#: bzrlib/builtins.py:3145
+#: bzrlib/builtins.py:3126
 msgid ""
 ":Examples:\n"
 "    Ignore the top level Makefile::"
 msgstr ""
 
-#: bzrlib/builtins.py:3148
+#: bzrlib/builtins.py:3129
 msgid "        bzr ignore ./Makefile"
 msgstr ""
 
-#: bzrlib/builtins.py:3150
+#: bzrlib/builtins.py:3131
 msgid "    Ignore .class files in all directories...::"
 msgstr ""
 
-#: bzrlib/builtins.py:3152
+#: bzrlib/builtins.py:3133
 msgid "        bzr ignore \"*.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:3154
+#: bzrlib/builtins.py:3135
 msgid "    ...but do not ignore \"special.class\"::"
 msgstr ""
 
-#: bzrlib/builtins.py:3156
+#: bzrlib/builtins.py:3137
 msgid "        bzr ignore \"!special.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:3158
+#: bzrlib/builtins.py:3139
 msgid "    Ignore files whose name begins with the \"#\" character::"
 msgstr ""
 
-#: bzrlib/builtins.py:3160
+#: bzrlib/builtins.py:3141
 msgid "        bzr ignore \"RE:^#\""
 msgstr ""
 
-#: bzrlib/builtins.py:3162 bzrlib/builtins.py:3166
+#: bzrlib/builtins.py:3143 bzrlib/builtins.py:3147
 msgid "    Ignore .o files under the lib directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:3164
+#: bzrlib/builtins.py:3145
 msgid "        bzr ignore \"lib/**/*.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:3168
+#: bzrlib/builtins.py:3149
 msgid "        bzr ignore \"RE:lib/.*\\.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:3170
+#: bzrlib/builtins.py:3151
 msgid "    Ignore everything but the \"debian\" toplevel directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:3172
+#: bzrlib/builtins.py:3153
 msgid ""
 "        bzr ignore \"RE:(?!debian/).*\"\n"
 "    \n"
@@ -1992,26 +1986,26 @@
 msgstr ""
 
 # help of 'default-rules' option of 'ignore' command
-#: bzrlib/builtins.py:3186
+#: bzrlib/builtins.py:3167
 msgid "Display the default ignore rules that bzr uses."
 msgstr ""
 
-#: bzrlib/builtins.py:3198
+#: bzrlib/builtins.py:3179
 msgid "ignore requires at least one NAME_PATTERN or --default-rules."
 msgstr ""
 
-#: bzrlib/builtins.py:3209
+#: bzrlib/builtins.py:3190
 #, python-format
 msgid "Invalid ignore pattern found. %s"
 msgid_plural "Invalid ignore patterns found. %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:3218
+#: bzrlib/builtins.py:3199
 msgid "NAME_PATTERN should not be an absolute path"
 msgstr ""
 
-#: bzrlib/builtins.py:3231
+#: bzrlib/builtins.py:3212
 #, python-format
 msgid ""
 "Warning: the following files are version controlled and match your ignore "
@@ -2021,62 +2015,62 @@
 "them.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:3238
+#: bzrlib/builtins.py:3219
 msgid "List ignored files and the patterns that matched them."
 msgstr ""
 
-#: bzrlib/builtins.py:3240
+#: bzrlib/builtins.py:3221
 msgid ""
 "List all the ignored files and the ignore pattern that caused the file to\n"
 "be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:3243
+#: bzrlib/builtins.py:3224
 msgid "Alternatively, to list just the files::"
 msgstr ""
 
-#: bzrlib/builtins.py:3245
+#: bzrlib/builtins.py:3226
 msgid "    bzr ls --ignored"
 msgstr ""
 
-#: bzrlib/builtins.py:3279
+#: bzrlib/builtins.py:3260
 #, python-format
 msgid "not a valid revision-number: %r"
 msgstr ""
 
-#: bzrlib/builtins.py:3286
+#: bzrlib/builtins.py:3267
 msgid "Export current or past revision to a destination directory or archive."
 msgstr ""
 
-#: bzrlib/builtins.py:3288
+#: bzrlib/builtins.py:3269
 msgid "If no revision is specified this exports the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:3290
+#: bzrlib/builtins.py:3271
 msgid ""
 "Format may be an \"exporter\" name, such as tar, tgz, tbz2.  If none is\n"
 "given, try to find the format with the extension. If no extension\n"
 "is found exports to a directory (equivalent to --format=dir)."
 msgstr ""
 
-#: bzrlib/builtins.py:3294
+#: bzrlib/builtins.py:3275
 msgid ""
 "If root is supplied, it will be used as the root directory inside\n"
 "container formats (tar, zip, etc). If it is not supplied it will default\n"
 "to the exported filename. The root option has no effect for 'dir' format."
 msgstr ""
 
-#: bzrlib/builtins.py:3298
+#: bzrlib/builtins.py:3279
 msgid ""
 "If branch is omitted then the branch containing the current working\n"
 "directory will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:3301
+#: bzrlib/builtins.py:3282
 msgid "Note: Export of tree with non-ASCII filenames to zip is not supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3303
+#: bzrlib/builtins.py:3284
 msgid ""
 "  =================       =========================\n"
 "  Supported formats       Autodetected by extension\n"
@@ -2090,78 +2084,78 @@
 msgstr ""
 
 # help of 'format' option of 'export' command
-#: bzrlib/builtins.py:3317
+#: bzrlib/builtins.py:3298
 msgid "Type of file to export to."
 msgstr ""
 
 # help of 'filters' option of 'export' command
-#: bzrlib/builtins.py:3320
+#: bzrlib/builtins.py:3301
 msgid "Apply content filters to export the convenient form."
 msgstr ""
 
 # help of 'root' option of 'export' command
-#: bzrlib/builtins.py:3324
+#: bzrlib/builtins.py:3305
 msgid "Name of the root directory inside the exported file."
 msgstr ""
 
 # help of 'per-file-timestamps' option of 'export' command
-#: bzrlib/builtins.py:3326
+#: bzrlib/builtins.py:3307
 msgid ""
 "Set modification time of files to that of the last revision in which it was "
 "changed."
 msgstr ""
 
 # help of 'uncommitted' option of 'export' command
+#: bzrlib/builtins.py:3310
+msgid "Export the working tree contents rather than that of the last revision."
+msgstr ""
+
 #: bzrlib/builtins.py:3329
-msgid "Export the working tree contents rather than that of the last revision."
-msgstr ""
-
-#: bzrlib/builtins.py:3348
 msgid "--uncommitted requires a working tree"
 msgstr ""
 
-#: bzrlib/builtins.py:3357
+#: bzrlib/builtins.py:3338
 #, python-format
 msgid "Unsupported export format: %s"
 msgstr ""
 
-#: bzrlib/builtins.py:3361
+#: bzrlib/builtins.py:3342
 msgid "Write the contents of a file as of a given revision to standard output."
 msgstr ""
 
-#: bzrlib/builtins.py:3363
+#: bzrlib/builtins.py:3344
 msgid "If no revision is nominated, the last revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:3365
+#: bzrlib/builtins.py:3346
 msgid ""
 "Note: Take care to redirect standard output when using this command on a\n"
 "binary file."
 msgstr ""
 
 # help of 'name-from-revision' option of 'cat' command
-#: bzrlib/builtins.py:3371
+#: bzrlib/builtins.py:3352
 msgid "The path name in the old tree."
 msgstr ""
 
 # help of 'filters' option of 'cat' command
-#: bzrlib/builtins.py:3372
+#: bzrlib/builtins.py:3353
 msgid "Apply content filters to display the convenience form."
 msgstr ""
 
-#: bzrlib/builtins.py:3383
+#: bzrlib/builtins.py:3364
 msgid "bzr cat --revision takes exactly one revision specifier"
 msgstr ""
 
-#: bzrlib/builtins.py:3408 bzrlib/builtins.py:3420
+#: bzrlib/builtins.py:3389 bzrlib/builtins.py:3401
 msgid "{0!r} is not present in revision {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:3443
+#: bzrlib/builtins.py:3424
 msgid "Commit changes into a new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:3445
+#: bzrlib/builtins.py:3426
 msgid ""
 "An explanatory message needs to be given for each commit. This is\n"
 "often done by using the --message option (getting the message from the\n"
@@ -2171,44 +2165,44 @@
 "boilerplate text loaded into the editor, use the --show-diff option."
 msgstr ""
 
-#: bzrlib/builtins.py:3452
+#: bzrlib/builtins.py:3433
 msgid ""
 "By default, the entire tree is committed and the person doing the\n"
 "commit is assumed to be the author. These defaults can be overridden\n"
 "as explained below."
 msgstr ""
 
-#: bzrlib/builtins.py:3456
+#: bzrlib/builtins.py:3437
 msgid ":Selective commits:"
 msgstr ""
 
-#: bzrlib/builtins.py:3458
+#: bzrlib/builtins.py:3439
 msgid ""
 "  If selected files are specified, only changes to those files are\n"
 "  committed.  If a directory is specified then the directory and\n"
 "  everything within it is committed."
 msgstr ""
 
-#: bzrlib/builtins.py:3462
+#: bzrlib/builtins.py:3443
 msgid ""
 "  When excludes are given, they take precedence over selected files.\n"
 "  For example, to commit only changes within foo, but not changes\n"
 "  within foo/bar::"
 msgstr ""
 
-#: bzrlib/builtins.py:3466
+#: bzrlib/builtins.py:3447
 msgid "    bzr commit foo -x foo/bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3468
+#: bzrlib/builtins.py:3449
 msgid "  A selective commit after a merge is not yet supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3470
+#: bzrlib/builtins.py:3451
 msgid ":Custom authors:"
 msgstr ""
 
-#: bzrlib/builtins.py:3472
+#: bzrlib/builtins.py:3453
 msgid ""
 "  If the author of the change is not the same person as the committer,\n"
 "  you can specify the author's name using the --author option. The\n"
@@ -2218,11 +2212,11 @@
 "  author."
 msgstr ""
 
-#: bzrlib/builtins.py:3479
+#: bzrlib/builtins.py:3460
 msgid ":Checks:"
 msgstr ""
 
-#: bzrlib/builtins.py:3481
+#: bzrlib/builtins.py:3462
 msgid ""
 "  A common mistake is to forget to add a new file or directory before\n"
 "  running the commit command. The --strict option checks for unknown\n"
@@ -2231,18 +2225,18 @@
 "  for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3487
+#: bzrlib/builtins.py:3468
 msgid ":Things to note:"
 msgstr ""
 
-#: bzrlib/builtins.py:3489
+#: bzrlib/builtins.py:3470
 msgid ""
 "  If you accidentially commit the wrong changes or make a spelling\n"
 "  mistake in the commit message say, you can use the uncommit command\n"
 "  to undo it. See ``bzr help uncommit`` for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3493
+#: bzrlib/builtins.py:3474
 msgid ""
 "  Hooks can also be configured to run after a commit. This allows you\n"
 "  to trigger updates to external systems like bug trackers. The --fixes\n"
@@ -2251,69 +2245,69 @@
 msgstr ""
 
 # help of 'exclude' option of 'commit' command
-#: bzrlib/builtins.py:3503
+#: bzrlib/builtins.py:3484
 msgid "Do not consider changes made to a given path."
 msgstr ""
 
 # help of 'message' option of 'commit' command
-#: bzrlib/builtins.py:3506
+#: bzrlib/builtins.py:3487
 msgid "Description of the new revision."
 msgstr ""
 
 # help of 'unchanged' option of 'commit' command
-#: bzrlib/builtins.py:3509
+#: bzrlib/builtins.py:3490
 msgid "Commit even if nothing has changed."
 msgstr ""
 
 # help of 'file' option of 'commit' command
-#: bzrlib/builtins.py:3513
+#: bzrlib/builtins.py:3494
 msgid "Take commit message from this file."
 msgstr ""
 
 # help of 'strict' option of 'commit' command
-#: bzrlib/builtins.py:3515
+#: bzrlib/builtins.py:3496
 msgid "Refuse to commit if there are unknown files in the working tree."
 msgstr ""
 
 # help of 'commit-time' option of 'commit' command
-#: bzrlib/builtins.py:3518
+#: bzrlib/builtins.py:3499
 msgid ""
 "Manually set a commit time using commit date format, e.g. '2009-10-10 "
 "08:00:00 +0100'."
 msgstr ""
 
 # help of 'fixes' option of 'commit' command
-#: bzrlib/builtins.py:3521
+#: bzrlib/builtins.py:3502
 msgid "Mark a bug as being fixed by this revision (see \"bzr help bugs\")."
 msgstr ""
 
 # help of 'author' option of 'commit' command
-#: bzrlib/builtins.py:3524
+#: bzrlib/builtins.py:3505
 msgid "Set the author's name, if it's different from the committer."
 msgstr ""
 
 # help of 'local' option of 'commit' command
-#: bzrlib/builtins.py:3527
+#: bzrlib/builtins.py:3508
 msgid ""
 "Perform a local commit in a bound branch.  Local commits are not pushed to "
 "the master branch until a normal commit is performed."
 msgstr ""
 
 # help of 'show-diff' option of 'commit' command
-#: bzrlib/builtins.py:3533
+#: bzrlib/builtins.py:3514
 msgid ""
 "When no message is supplied, show the diff along with the status summary in "
 "the message editor."
 msgstr ""
 
 # help of 'lossy' option of 'commit' command
-#: bzrlib/builtins.py:3536
+#: bzrlib/builtins.py:3517
 msgid ""
 "When committing to a foreign version control system do not push data that "
 "can not be natively represented."
 msgstr ""
 
-#: bzrlib/builtins.py:3554
+#: bzrlib/builtins.py:3535
 #, python-format
 msgid ""
 "No tracker specified for bug %s. Use the form 'tracker:id' or specify a "
@@ -2321,7 +2315,7 @@
 "See \"bzr help bugs\" for more information on this feature. Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3563
+#: bzrlib/builtins.py:3544
 #, python-format
 msgid ""
 "Invalid bug %s. Must be in the form of 'tracker:id'. See \"bzr help bugs\" "
@@ -2329,91 +2323,91 @@
 "Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3572
+#: bzrlib/builtins.py:3553
 #, python-format
 msgid "Unrecognized bug %s. Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3575
+#: bzrlib/builtins.py:3556
 #, python-format
 msgid ""
 "%s\n"
 "Commit refused."
 msgstr ""
 
-#: bzrlib/builtins.py:3599
+#: bzrlib/builtins.py:3580
 msgid "Could not parse --commit-time: "
 msgstr ""
 
-#: bzrlib/builtins.py:3639
+#: bzrlib/builtins.py:3620
 msgid "please specify either --message or --file"
 msgstr ""
 
-#: bzrlib/builtins.py:3668
+#: bzrlib/builtins.py:3649
 msgid "please specify a commit message with either --message or --file"
 msgstr ""
 
-#: bzrlib/builtins.py:3671
+#: bzrlib/builtins.py:3652
 msgid ""
 "Empty commit message specified. Please specify a commit message with either "
 "--message or --file or leave a blank message with --message \"\"."
 msgstr ""
 
-#: bzrlib/builtins.py:3691
+#: bzrlib/builtins.py:3672
 msgid ""
 "No changes to commit. Please 'bzr add' the files you want to commit, or use "
 "--unchanged to force an empty commit."
 msgstr ""
 
-#: bzrlib/builtins.py:3695
+#: bzrlib/builtins.py:3676
 msgid ""
 "Conflicts detected in working tree.  Use \"bzr conflicts\" to list, \"bzr "
 "resolve FILE\" to resolve."
 msgstr ""
 
-#: bzrlib/builtins.py:3699
+#: bzrlib/builtins.py:3680
 msgid "Commit refused because there are unknown files in the working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:3702
+#: bzrlib/builtins.py:3683
 msgid ""
 "\n"
 "To commit to master branch, run update and then commit.\n"
 "You can also pass --local to commit to continue working disconnected."
 msgstr ""
 
-#: bzrlib/builtins.py:3710
+#: bzrlib/builtins.py:3691
 msgid ""
 "Validate working tree structure, branch consistency and repository history."
 msgstr ""
 
-#: bzrlib/builtins.py:3712
+#: bzrlib/builtins.py:3693
 msgid ""
 "This command checks various invariants about branch and repository storage\n"
 "to detect data corruption or bzr bugs."
 msgstr ""
 
-#: bzrlib/builtins.py:3715
+#: bzrlib/builtins.py:3696
 msgid ""
 "The working tree and branch checks will only give output if a problem is\n"
 "detected. The output fields of the repository check are:"
 msgstr ""
 
-#: bzrlib/builtins.py:3718
+#: bzrlib/builtins.py:3699
 msgid ""
 "revisions\n"
 "    This is just the number of revisions checked.  It doesn't\n"
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3722
+#: bzrlib/builtins.py:3703
 msgid ""
 "versionedfiles\n"
 "    This is just the number of versionedfiles checked.  It\n"
 "    doesn't indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3726
+#: bzrlib/builtins.py:3707
 msgid ""
 "unreferenced ancestors\n"
 "    Texts that are ancestors of other texts, but\n"
@@ -2421,14 +2415,14 @@
 "    subtle problem that Bazaar can work around."
 msgstr ""
 
-#: bzrlib/builtins.py:3731
+#: bzrlib/builtins.py:3712
 msgid ""
 "unique file texts\n"
 "    This is the total number of unique file contents\n"
 "    seen in the checked revisions.  It does not indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3735
+#: bzrlib/builtins.py:3716
 msgid ""
 "repeated file texts\n"
 "    This is the total number of repeated texts seen\n"
@@ -2437,57 +2431,57 @@
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3741
+#: bzrlib/builtins.py:3722
 msgid ""
 "If no restrictions are specified, all Bazaar data that is found at the "
 "given\n"
 "location will be checked."
 msgstr ""
 
-#: bzrlib/builtins.py:3746
+#: bzrlib/builtins.py:3727
 msgid "    Check the tree and branch at 'foo'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3748
+#: bzrlib/builtins.py:3729
 msgid "        bzr check --tree --branch foo"
 msgstr ""
 
-#: bzrlib/builtins.py:3750
+#: bzrlib/builtins.py:3731
 msgid "    Check only the repository at 'bar'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3752
+#: bzrlib/builtins.py:3733
 msgid "        bzr check --repo bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3754
+#: bzrlib/builtins.py:3735
 msgid "    Check everything at 'baz'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3756
+#: bzrlib/builtins.py:3737
 msgid "        bzr check baz"
 msgstr ""
 
 # help of 'branch' option of 'check' command
-#: bzrlib/builtins.py:3762
+#: bzrlib/builtins.py:3743
 msgid "Check the branch related to the current directory."
 msgstr ""
 
 # help of 'repo' option of 'check' command
-#: bzrlib/builtins.py:3764
+#: bzrlib/builtins.py:3745
 msgid "Check the repository related to the current directory."
 msgstr ""
 
 # help of 'tree' option of 'check' command
-#: bzrlib/builtins.py:3766
+#: bzrlib/builtins.py:3747
 msgid "Check the working tree related to the current directory."
 msgstr ""
 
-#: bzrlib/builtins.py:3780
+#: bzrlib/builtins.py:3761
 msgid "Upgrade a repository, branch or working tree to a newer format."
 msgstr ""
 
-#: bzrlib/builtins.py:3782
+#: bzrlib/builtins.py:3763
 msgid ""
 "When the default format has changed after a major new release of\n"
 "Bazaar, you may be informed during certain operations that you\n"
@@ -2496,7 +2490,7 @@
 "with older repositories or with older versions of Bazaar."
 msgstr ""
 
-#: bzrlib/builtins.py:3788
+#: bzrlib/builtins.py:3769
 msgid ""
 "If you wish to upgrade to a particular format rather than the\n"
 "current default, that can be specified using the --format option.\n"
@@ -2506,7 +2500,7 @@
 "2.x default) so downgrading is not always possible."
 msgstr ""
 
-#: bzrlib/builtins.py:3795
+#: bzrlib/builtins.py:3776
 msgid ""
 "A backup.bzr.~#~ directory is created at the start of the conversion\n"
 "process (where # is a number). By default, this is left there on\n"
@@ -2517,7 +2511,7 @@
 "afterwards."
 msgstr ""
 
-#: bzrlib/builtins.py:3803
+#: bzrlib/builtins.py:3784
 msgid ""
 "If the location given is a shared repository, dependent branches\n"
 "are also converted provided the repository converts successfully.\n"
@@ -2525,166 +2519,166 @@
 "tried."
 msgstr ""
 
-#: bzrlib/builtins.py:3808
+#: bzrlib/builtins.py:3789
 msgid ""
 "For more information on upgrades, see the Bazaar Upgrade Guide,\n"
 "http://doc.bazaar.canonical.com/latest/en/upgrade-guide/."
 msgstr ""
 
 # help of 'format' option of 'upgrade' command
-#: bzrlib/builtins.py:3816
+#: bzrlib/builtins.py:3797
 msgid "Upgrade to a specific format.  See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init' command
 # title of 'format' option of 'upgrade' command
-#: bzrlib/builtins.py:3820
+#: bzrlib/builtins.py:3801
 msgid "Branch format"
 msgstr ""
 
 # help of 'clean' option of 'upgrade' command
-#: bzrlib/builtins.py:3822
+#: bzrlib/builtins.py:3803
 msgid "Remove the backup.bzr directory if successful."
 msgstr ""
 
 # help of 'dry-run' option of 'add' command
 # help of 'dry-run' option of 'upgrade' command
-#: bzrlib/builtins.py:3824
+#: bzrlib/builtins.py:3805
 msgid "Show what would be done, but don't actually do anything."
 msgstr ""
 
-#: bzrlib/builtins.py:3839
+#: bzrlib/builtins.py:3820
 msgid "Show or set bzr user id."
 msgstr ""
 
-#: bzrlib/builtins.py:3841
+#: bzrlib/builtins.py:3822
 msgid ""
 ":Examples:\n"
 "    Show the email of the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3844
+#: bzrlib/builtins.py:3825
 msgid "        bzr whoami --email"
 msgstr ""
 
-#: bzrlib/builtins.py:3846
+#: bzrlib/builtins.py:3827
 msgid "    Set the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3848
+#: bzrlib/builtins.py:3829
 msgid "        bzr whoami \"Frank Chu <fchu@example.com>\""
 msgstr ""
 
 # help of 'email' option of 'whoami' command
-#: bzrlib/builtins.py:3852
+#: bzrlib/builtins.py:3833
 msgid "Display email address only."
 msgstr ""
 
 # help of 'branch' option of 'whoami' command
-#: bzrlib/builtins.py:3854
+#: bzrlib/builtins.py:3835
 msgid "Set identity for the current branch instead of globally."
 msgstr ""
 
-#: bzrlib/builtins.py:3880
+#: bzrlib/builtins.py:3861
 msgid "--email can only be used to display existing identity"
 msgstr ""
 
-#: bzrlib/builtins.py:3904
+#: bzrlib/builtins.py:3885
 msgid "Print or set the branch nickname."
 msgstr ""
 
-#: bzrlib/builtins.py:3906
+#: bzrlib/builtins.py:3887
 msgid ""
 "If unset, the colocated branch name is used for colocated branches, and\n"
 "the branch directory name is used for other branches.  To print the\n"
 "current nickname, execute with no argument."
 msgstr ""
 
-#: bzrlib/builtins.py:3910
+#: bzrlib/builtins.py:3891
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally."
 msgstr ""
 
-#: bzrlib/builtins.py:3930
+#: bzrlib/builtins.py:3911
 msgid "Set/unset and display aliases."
 msgstr ""
 
-#: bzrlib/builtins.py:3932
+#: bzrlib/builtins.py:3913
 msgid ""
 ":Examples:\n"
 "    Show the current aliases::"
 msgstr ""
 
-#: bzrlib/builtins.py:3935
+#: bzrlib/builtins.py:3916
 msgid "        bzr alias"
 msgstr ""
 
-#: bzrlib/builtins.py:3937
+#: bzrlib/builtins.py:3918
 msgid "    Show the alias specified for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3939
+#: bzrlib/builtins.py:3920
 msgid "        bzr alias ll"
 msgstr ""
 
-#: bzrlib/builtins.py:3941
+#: bzrlib/builtins.py:3922
 msgid "    Set an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3943
+#: bzrlib/builtins.py:3924
 msgid "        bzr alias ll=\"log --line -r-10..-1\""
 msgstr ""
 
-#: bzrlib/builtins.py:3945
+#: bzrlib/builtins.py:3926
 msgid "    To remove an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3947
+#: bzrlib/builtins.py:3928
 msgid "        bzr alias --remove ll"
 msgstr ""
 
 # help of 'remove' option of 'alias' command
-#: bzrlib/builtins.py:3952
+#: bzrlib/builtins.py:3933
 msgid "Remove the alias."
 msgstr ""
 
-#: bzrlib/builtins.py:3970
+#: bzrlib/builtins.py:3951
 msgid "bzr alias --remove expects an alias to remove."
 msgstr ""
 
-#: bzrlib/builtins.py:4151
+#: bzrlib/builtins.py:4132
 msgid "subunit not available. subunit needs to be installed to use --subunit."
 msgstr ""
 
-#: bzrlib/builtins.py:4168
+#: bzrlib/builtins.py:4149
 msgid ""
 "--benchmark is no longer supported from bzr 2.2; use bzr-usertest instead"
 msgstr ""
 
-#: bzrlib/builtins.py:4215
+#: bzrlib/builtins.py:4196
 msgid "Show version of bzr."
 msgstr ""
 
 # help of 'short' option of 'version' command
+#: bzrlib/builtins.py:4200
+msgid "Print just the version number."
+msgstr ""
+
 #: bzrlib/builtins.py:4219
-msgid "Print just the version number."
-msgstr ""
-
-#: bzrlib/builtins.py:4238
 msgid "It sure does!\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4262
+#: bzrlib/builtins.py:4243
 #, python-format
 msgid "merge base is revision %s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:4266
+#: bzrlib/builtins.py:4247
 msgid "Perform a three-way merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4268
+#: bzrlib/builtins.py:4249
 msgid ""
 "The source of the merge can be specified either in the form of a branch,\n"
 "or in the form of a path to a file containing a merge directive generated\n"
@@ -2695,20 +2689,20 @@
 "the current working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:4276
+#: bzrlib/builtins.py:4257
 msgid ""
 "When merging from a branch, by default bzr will try to merge in all new\n"
 "work from the other branch, automatically determining an appropriate base\n"
 "revision.  If this fails, you may need to give an explicit base."
 msgstr ""
 
-#: bzrlib/builtins.py:4280
+#: bzrlib/builtins.py:4261
 msgid ""
 "To pick a different ending revision, pass \"--revision OTHER\".  bzr will\n"
 "try to merge in all new work up to and including revision OTHER."
 msgstr ""
 
-#: bzrlib/builtins.py:4283
+#: bzrlib/builtins.py:4264
 msgid ""
 "If you specify two values, \"--revision BASE..OTHER\", only revisions BASE\n"
 "through OTHER, excluding BASE but including OTHER, will be merged.  If this\n"
@@ -2719,11 +2713,11 @@
 "changes from the other branch is not stored in the commit."
 msgstr ""
 
-#: bzrlib/builtins.py:4291
+#: bzrlib/builtins.py:4272
 msgid "Revision numbers are always relative to the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:4293 bzrlib/conflicts.py:52 bzrlib/conflicts.py:106
+#: bzrlib/builtins.py:4274 bzrlib/conflicts.py:52 bzrlib/conflicts.py:106
 msgid ""
 "Merge will do its best to combine the changes in two branches, but there\n"
 "are some kinds of problems only a human can fix.  When it encounters those,\n"
@@ -2731,11 +2725,11 @@
 "before you can commit."
 msgstr ""
 
-#: bzrlib/builtins.py:4298
+#: bzrlib/builtins.py:4279
 msgid "Use bzr resolve when you have fixed a problem.  See also bzr conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:4300
+#: bzrlib/builtins.py:4281
 msgid ""
 "If there is no default branch set, the first merge will set it (use\n"
 "--no-remember to avoid setting it). After that, you can omit the branch\n"
@@ -2743,14 +2737,14 @@
 "only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:4305
+#: bzrlib/builtins.py:4286
 msgid ""
 "The results of the merge are placed into the destination working\n"
 "directory, where they can be reviewed (with bzr diff), tested, and then\n"
 "committed to record the result of the merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4309
+#: bzrlib/builtins.py:4290
 msgid ""
 "merge refuses to run if there are any uncommitted changes, unless\n"
 "--force is given.  If --force is given, then the changes from the source \n"
@@ -2759,60 +2753,60 @@
 "merge revision which has more than two parents."
 msgstr ""
 
-#: bzrlib/builtins.py:4315
+#: bzrlib/builtins.py:4296
 msgid ""
 "If one would like to merge changes from the working tree of the other\n"
 "branch without merging any committed revisions, the --uncommitted option\n"
 "can be given."
 msgstr ""
 
-#: bzrlib/builtins.py:4319
+#: bzrlib/builtins.py:4300
 msgid ""
 "To select only some changes to merge, use \"merge -i\", which will prompt\n"
 "you to apply each diff hunk and file change, similar to \"shelve\"."
 msgstr ""
 
-#: bzrlib/builtins.py:4322
+#: bzrlib/builtins.py:4303
 msgid ""
 ":Examples:\n"
 "    To merge all new revisions from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:4325
+#: bzrlib/builtins.py:4306
 msgid "        bzr merge ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4327
+#: bzrlib/builtins.py:4308
 msgid "    To merge changes up to and including revision 82 from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:4329
+#: bzrlib/builtins.py:4310
 msgid "        bzr merge -r 82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4331
+#: bzrlib/builtins.py:4312
 msgid "    To merge the changes introduced by 82, without previous changes::"
 msgstr ""
 
-#: bzrlib/builtins.py:4333
+#: bzrlib/builtins.py:4314
 msgid "        bzr merge -r 81..82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4335
+#: bzrlib/builtins.py:4316
 msgid "    To apply a merge directive contained in /tmp/merge::"
 msgstr ""
 
-#: bzrlib/builtins.py:4337
+#: bzrlib/builtins.py:4318
 msgid "        bzr merge /tmp/merge"
 msgstr ""
 
-#: bzrlib/builtins.py:4339
+#: bzrlib/builtins.py:4320
 msgid ""
 "    To create a merge revision with three parents from two branches\n"
 "    feature1a and feature1b:"
 msgstr ""
 
-#: bzrlib/builtins.py:4342
+#: bzrlib/builtins.py:4323
 msgid ""
 "        bzr merge ../feature1a\n"
 "        bzr merge ../feature1b --force\n"
@@ -2820,18 +2814,18 @@
 msgstr ""
 
 # help of 'force' option of 'merge' command
-#: bzrlib/builtins.py:4354
+#: bzrlib/builtins.py:4335
 msgid "Merge even if the destination tree has uncommitted changes."
 msgstr ""
 
 # help of 'uncommitted' option of 'merge' command
-#: bzrlib/builtins.py:4360
+#: bzrlib/builtins.py:4341
 msgid ""
 "Apply uncommitted changes from a working copy, instead of branch changes."
 msgstr ""
 
 # help of 'pull' option of 'merge' command
-#: bzrlib/builtins.py:4362
+#: bzrlib/builtins.py:4343
 msgid ""
 "If the destination is already completely merged into the source, pull from "
 "the source rather than merging.  When this happens, you do not need to "
@@ -2839,109 +2833,109 @@
 msgstr ""
 
 # help of 'directory' option of 'merge' command
-#: bzrlib/builtins.py:4367
+#: bzrlib/builtins.py:4348
 msgid ""
 "Branch to merge into, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'preview' option of 'merge' command
-#: bzrlib/builtins.py:4369
+#: bzrlib/builtins.py:4350
 msgid "Instead of merging, show a diff of the merge."
 msgstr ""
 
 # help of 'interactive' option of 'merge' command
-#: bzrlib/builtins.py:4371
+#: bzrlib/builtins.py:4352
 msgid "Select changes interactively."
 msgstr ""
 
-#: bzrlib/builtins.py:4393
+#: bzrlib/builtins.py:4374
 msgid ""
 "Merging into empty branches not currently supported, https://bugs.launchpad."
 "net/bzr/+bug/308562"
 msgstr ""
 
-#: bzrlib/builtins.py:4420
+#: bzrlib/builtins.py:4401
 msgid "Cannot use --uncommitted with bundles or merge directives."
 msgstr ""
 
-#: bzrlib/builtins.py:4431
+#: bzrlib/builtins.py:4412
 msgid "Cannot use --uncommitted and --revision at the same time."
 msgstr ""
 
-#: bzrlib/builtins.py:4451
+#: bzrlib/builtins.py:4432
 msgid "merger: "
 msgstr ""
 
-#: bzrlib/builtins.py:4453 bzrlib/bundle/apply_bundle.py:71
+#: bzrlib/builtins.py:4434 bzrlib/bundle/apply_bundle.py:71
 msgid "Nothing to do."
 msgstr ""
 
-#: bzrlib/builtins.py:4457
+#: bzrlib/builtins.py:4438
 msgid "Cannot pull individual files"
 msgstr ""
 
-#: bzrlib/builtins.py:4465
+#: bzrlib/builtins.py:4446
 msgid "This branch has no commits. (perhaps you would prefer 'bzr pull')"
 msgstr ""
 
-#: bzrlib/builtins.py:4523
+#: bzrlib/builtins.py:4504
 #, python-format
 msgid "Show-base is not supported for this merge type. %s"
 msgstr ""
 
-#: bzrlib/builtins.py:4532
+#: bzrlib/builtins.py:4513
 #, python-format
 msgid "Conflict reduction is not supported for merge type %s."
 msgstr ""
 
-#: bzrlib/builtins.py:4536
+#: bzrlib/builtins.py:4517
 msgid "Cannot do conflict reduction and show base."
 msgstr ""
 
-#: bzrlib/builtins.py:4647
+#: bzrlib/builtins.py:4628
 msgid "No location specified or remembered"
 msgstr ""
 
-#: bzrlib/builtins.py:4649
+#: bzrlib/builtins.py:4630
 msgid "{0} remembered {1} location {2}"
 msgstr ""
 
-#: bzrlib/builtins.py:4655
+#: bzrlib/builtins.py:4636
 msgid "Redo a merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4657
+#: bzrlib/builtins.py:4638
 msgid ""
 "Use this if you want to try a different merge technique while resolving\n"
 "conflicts.  Some merge techniques are better than others, and remerge\n"
 "lets you try different ones on different files."
 msgstr ""
 
-#: bzrlib/builtins.py:4661
+#: bzrlib/builtins.py:4642
 msgid ""
 "The options for remerge have the same meaning and defaults as the ones for\n"
 "merge.  The difference is that remerge can (only) be run when there is a\n"
 "pending merge, and it lets you specify particular files."
 msgstr ""
 
-#: bzrlib/builtins.py:4665
+#: bzrlib/builtins.py:4646
 msgid ""
 ":Examples:\n"
 "    Re-do the merge of all conflicted files, and show the base text in\n"
 "    conflict regions, in addition to the usual THIS and OTHER texts::"
 msgstr ""
 
-#: bzrlib/builtins.py:4669
+#: bzrlib/builtins.py:4650
 msgid "        bzr remerge --show-base"
 msgstr ""
 
-#: bzrlib/builtins.py:4671
+#: bzrlib/builtins.py:4652
 msgid ""
 "    Re-do the merge of \"foobar\", using the weave merge algorithm, with\n"
 "    additional processing to reduce the size of conflict regions::"
 msgstr ""
 
-#: bzrlib/builtins.py:4674
+#: bzrlib/builtins.py:4655
 msgid "        bzr remerge --merge-type weave --reprocess foobar"
 msgstr ""
 
@@ -2949,51 +2943,44 @@
 # help of 'show-base' option of 'pull' command
 # help of 'show-base' option of 'remerge' command
 # help of 'show-base' option of 'update' command
-#: bzrlib/builtins.py:4681
+#: bzrlib/builtins.py:4662
 msgid "Show base revision text in conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:4693
+#: bzrlib/builtins.py:4674
 msgid ""
 "Sorry, remerge only works after normal merges.  Not cherrypicking or multi-"
 "merges."
 msgstr ""
 
-#: bzrlib/builtins.py:4751
-msgid ""
-"Set files in the working tree back to the contents of a previous revision."
+#: bzrlib/builtins.py:4731
+msgid "Revert files to a previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:4753
+#: bzrlib/builtins.py:4733
 msgid ""
 "Giving a list of files will revert only those files.  Otherwise, all files\n"
 "will be reverted.  If the revision is not specified with '--revision', the\n"
-"working tree basis revision is used. A revert operation affects only the\n"
-"working tree, not any revision history like the branch and repository or\n"
-"the working tree basis revision."
+"last committed revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:4759
+#: bzrlib/builtins.py:4737
 msgid ""
 "To remove only some changes, without reverting to a prior version, use\n"
 "merge instead.  For example, \"merge . -r -2..-3\" (don't forget the \".\")\n"
 "will remove the changes introduced by the second last commit (-2), without\n"
 "affecting the changes introduced by the last commit (-1).  To remove\n"
-"certain changes on a hunk-by-hunk basis, see the shelve command.\n"
-"To update the branch to a specific revision or the latest revision and\n"
-"update the working tree accordingly while preserving local changes, see the\n"
-"update command."
+"certain changes on a hunk-by-hunk basis, see the shelve command."
 msgstr ""
 
-#: bzrlib/builtins.py:4768
+#: bzrlib/builtins.py:4743
 msgid ""
-"Uncommitted changes to files that are reverted will be discarded.\n"
-"Howver, by default, any files that have been manually changed will be\n"
-"backed up first.  (Files changed only by merge are not backed up.)  Backup\n"
-"files have '.~#~' appended to their name, where # is a number."
+"By default, any files that have been manually changed will be backed up\n"
+"first.  (Files changed only by merge are not backed up.)  Backup files have\n"
+"'.~#~' appended to their name, where # is a number."
 msgstr ""
 
-#: bzrlib/builtins.py:4773
+#: bzrlib/builtins.py:4747
 msgid ""
 "When you provide files, you can use their current pathname or the pathname\n"
 "from the target revision.  So you can use revert to \"undelete\" a file by\n"
@@ -3001,7 +2988,7 @@
 "reverted."
 msgstr ""
 
-#: bzrlib/builtins.py:4778
+#: bzrlib/builtins.py:4752
 msgid ""
 "If you have newly added files since the target revision, they will be\n"
 "removed.  If the files to be removed have been changed, backups will be\n"
@@ -3009,7 +2996,7 @@
 "deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:4783
+#: bzrlib/builtins.py:4757
 msgid ""
 "The working tree contains a list of revisions that have been merged but\n"
 "not yet committed. These revisions will be included as additional parents\n"
@@ -3021,7 +3008,7 @@
 "reverting any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4792
+#: bzrlib/builtins.py:4766
 msgid ""
 "Using \"bzr revert --forget-merges\", it is possible to apply all of the\n"
 "changes from a branch in a single revision.  To do this, perform the merge\n"
@@ -3036,35 +3023,35 @@
 msgstr ""
 
 # help of 'no-backup' option of 'revert' command
-#: bzrlib/builtins.py:4806
+#: bzrlib/builtins.py:4780
 msgid "Do not save backups of reverted files."
 msgstr ""
 
 # help of 'forget-merges' option of 'revert' command
-#: bzrlib/builtins.py:4808
+#: bzrlib/builtins.py:4782
 msgid "Remove pending merge marker, without changing any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4839
+#: bzrlib/builtins.py:4813
 msgid ""
 "Show help on a command or other topic.\n"
 "    "
 msgstr ""
 
 # help of 'long' option of 'help' command
-#: bzrlib/builtins.py:4844
+#: bzrlib/builtins.py:4818
 msgid "Show help on all commands."
 msgstr ""
 
-#: bzrlib/builtins.py:4873
+#: bzrlib/builtins.py:4847
 msgid "Show unmerged/unpulled revisions between two branches."
 msgstr ""
 
-#: bzrlib/builtins.py:4875
+#: bzrlib/builtins.py:4849
 msgid "OTHER_BRANCH may be local or remote."
 msgstr ""
 
-#: bzrlib/builtins.py:4877
+#: bzrlib/builtins.py:4851
 msgid ""
 "To filter on a range of revisions, you can use the command -r begin..end\n"
 "-r revision requests a specific revision, -r ..end or -r begin.. are\n"
@@ -3075,134 +3062,134 @@
 "    0 - no missing revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:4887
+#: bzrlib/builtins.py:4861
 msgid ""
 "    Determine the missing revisions between this and the branch at the\n"
 "    remembered pull location::"
 msgstr ""
 
-#: bzrlib/builtins.py:4890
+#: bzrlib/builtins.py:4864
 msgid "        bzr missing"
 msgstr ""
 
-#: bzrlib/builtins.py:4892
+#: bzrlib/builtins.py:4866
 msgid "    Determine the missing revisions between this and another branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4894
+#: bzrlib/builtins.py:4868
 msgid "        bzr missing http://server/branch"
 msgstr ""
 
-#: bzrlib/builtins.py:4896
+#: bzrlib/builtins.py:4870
 msgid ""
 "    Determine the missing revisions up to a specific revision on the other\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4899
+#: bzrlib/builtins.py:4873
 msgid "        bzr missing -r ..-10"
 msgstr ""
 
-#: bzrlib/builtins.py:4901
+#: bzrlib/builtins.py:4875
 msgid ""
 "    Determine the missing revisions up to a specific revision on this\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4904
+#: bzrlib/builtins.py:4878
 msgid "        bzr missing --my-revision ..-10"
 msgstr ""
 
 # help of 'reverse' option of 'missing' command
-#: bzrlib/builtins.py:4911
+#: bzrlib/builtins.py:4885
 msgid "Reverse the order of revisions."
 msgstr ""
 
 # help of 'mine-only' option of 'missing' command
-#: bzrlib/builtins.py:4913
+#: bzrlib/builtins.py:4887
 msgid "Display changes in the local branch only."
 msgstr ""
 
 # help of 'this' option of 'missing' command
-#: bzrlib/builtins.py:4914
+#: bzrlib/builtins.py:4888
 msgid "Same as --mine-only."
 msgstr ""
 
 # help of 'theirs-only' option of 'missing' command
-#: bzrlib/builtins.py:4916
+#: bzrlib/builtins.py:4890
 msgid "Display changes in the remote branch only."
 msgstr ""
 
 # help of 'other' option of 'missing' command
-#: bzrlib/builtins.py:4917
+#: bzrlib/builtins.py:4891
 msgid "Same as --theirs-only."
 msgstr ""
 
 # help of 'revision' option of 'missing' command
-#: bzrlib/builtins.py:4922
+#: bzrlib/builtins.py:4896
 msgid ""
 "Filter on other branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
 # help of 'my-revision' option of 'missing' command
-#: bzrlib/builtins.py:4926
+#: bzrlib/builtins.py:4900
 msgid ""
 "Filter on local branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
 # help of 'include-merged' option of 'missing' command
-#: bzrlib/builtins.py:4929
+#: bzrlib/builtins.py:4903
 msgid "Show all revisions in addition to the mainline ones."
 msgstr ""
 
-#: bzrlib/builtins.py:4983
+#: bzrlib/builtins.py:4957
 msgid "No peer location known or specified."
 msgstr ""
 
-#: bzrlib/builtins.py:4987
+#: bzrlib/builtins.py:4961
 msgid "Using saved parent location: {0}\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5020
+#: bzrlib/builtins.py:4994
 #, python-format
 msgid "You have %d extra revision:\n"
 msgid_plural "You have %d extra revisions:\n"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:5040
+#: bzrlib/builtins.py:5010
 #, python-format
 msgid "You are missing %d revision:\n"
 msgid_plural "You are missing %d revisions:\n"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/builtins.py:5055
+#: bzrlib/builtins.py:5022
 msgid "This branch has no new revisions.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5058
+#: bzrlib/builtins.py:5025
 msgid "Other branch has no new revisions.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5063
+#: bzrlib/builtins.py:5030
 msgid "Branches are up to date.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5074
+#: bzrlib/builtins.py:5041
 msgid "Compress the data within a repository."
 msgstr ""
 
-#: bzrlib/builtins.py:5076
+#: bzrlib/builtins.py:5043
 msgid ""
 "This operation compresses the data within a bazaar repository. As\n"
 "bazaar supports automatic packing of repository, this operation is\n"
 "normally not required to be done manually."
 msgstr ""
 
-#: bzrlib/builtins.py:5080
+#: bzrlib/builtins.py:5047
 msgid ""
 "During the pack operation, bazaar takes a backup of existing repository\n"
 "data, i.e. pack files. This backup is eventually removed by bazaar\n"
@@ -3211,7 +3198,7 @@
 "used."
 msgstr ""
 
-#: bzrlib/builtins.py:5086
+#: bzrlib/builtins.py:5053
 msgid ""
 "Warning: If you use --clean-obsolete-packs and your machine crashes\n"
 "during or immediately after repacking, you may be left with a state\n"
@@ -3220,25 +3207,25 @@
 msgstr ""
 
 # help of 'clean-obsolete-packs' option of 'pack' command
-#: bzrlib/builtins.py:5095
+#: bzrlib/builtins.py:5062
 msgid "Delete obsolete packs to save disk space."
 msgstr ""
 
-#: bzrlib/builtins.py:5109
+#: bzrlib/builtins.py:5076
 msgid "List the installed plugins."
 msgstr ""
 
-#: bzrlib/builtins.py:5111
+#: bzrlib/builtins.py:5078
 msgid ""
 "This command displays the list of installed plugins including\n"
 "version of plugin and a short description of each."
 msgstr ""
 
-#: bzrlib/builtins.py:5114
+#: bzrlib/builtins.py:5081
 msgid "--verbose shows the path where each plugin is located."
 msgstr ""
 
-#: bzrlib/builtins.py:5116
+#: bzrlib/builtins.py:5083
 msgid ""
 "A plugin is an external component for Bazaar that extends the\n"
 "revision control system, by adding or replacing code in Bazaar.\n"
@@ -3247,7 +3234,7 @@
 "customizing log output."
 msgstr ""
 
-#: bzrlib/builtins.py:5122
+#: bzrlib/builtins.py:5089
 msgid ""
 "See the Bazaar Plugin Guide <http://doc.bazaar.canonical.com/plugins/en/>\n"
 "for further information on plugins including where to find them and how to\n"
@@ -3255,122 +3242,122 @@
 "plugins using the Python programming language."
 msgstr ""
 
-#: bzrlib/builtins.py:5138
+#: bzrlib/builtins.py:5105
 msgid "Show testament (signing-form) of a revision."
 msgstr ""
 
 # help of 'long' option of 'testament' command
-#: bzrlib/builtins.py:5141
+#: bzrlib/builtins.py:5108
 msgid "Produce long-format testament."
 msgstr ""
 
 # help of 'strict' option of 'testament' command
-#: bzrlib/builtins.py:5143
+#: bzrlib/builtins.py:5110
 msgid "Produce a strict-format testament."
 msgstr ""
 
-#: bzrlib/builtins.py:5169
+#: bzrlib/builtins.py:5136
 msgid "Show the origin of each line in a file."
 msgstr ""
 
-#: bzrlib/builtins.py:5171
+#: bzrlib/builtins.py:5138
 msgid ""
 "This prints out the given file with an annotation on the left side\n"
 "indicating which revision, author and date introduced the change."
 msgstr ""
 
-#: bzrlib/builtins.py:5174
+#: bzrlib/builtins.py:5141
 msgid ""
 "If the origin is the same for a run of consecutive lines, it is\n"
 "shown only at the top, unless the --all option is given."
 msgstr ""
 
 # help of 'all' option of 'annotate' command
-#: bzrlib/builtins.py:5182
+#: bzrlib/builtins.py:5149
 msgid "Show annotations on all lines."
 msgstr ""
 
 # help of 'long' option of 'annotate' command
-#: bzrlib/builtins.py:5183
+#: bzrlib/builtins.py:5150
 msgid "Show commit date in annotations."
 msgstr ""
 
-#: bzrlib/builtins.py:5270
+#: bzrlib/builtins.py:5237
 msgid "Cannot sign a range of non-revision-history revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:5282
+#: bzrlib/builtins.py:5249
 msgid "Please supply either one revision, or a range."
 msgstr ""
 
-#: bzrlib/builtins.py:5286
+#: bzrlib/builtins.py:5253
 msgid ""
 "Convert the current branch into a checkout of the supplied branch.\n"
 "If no branch is supplied, rebind to the last bound location."
 msgstr ""
 
-#: bzrlib/builtins.py:5289
+#: bzrlib/builtins.py:5256
 msgid ""
 "Once converted into a checkout, commits must succeed on the master branch\n"
 "before they will be applied to the local branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5292
+#: bzrlib/builtins.py:5259
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case binding will update the local nickname to be\n"
 "that of the master."
 msgstr ""
 
-#: bzrlib/builtins.py:5307
+#: bzrlib/builtins.py:5274
 msgid "No location supplied.  This format does not remember old locations."
 msgstr ""
 
-#: bzrlib/builtins.py:5313
+#: bzrlib/builtins.py:5280
 msgid "Branch is already bound"
 msgstr ""
 
-#: bzrlib/builtins.py:5316
+#: bzrlib/builtins.py:5283
 msgid "No location supplied and no previous location known"
 msgstr ""
 
-#: bzrlib/builtins.py:5322
+#: bzrlib/builtins.py:5289
 msgid "These branches have diverged. Try merging, and then bind again."
 msgstr ""
 
-#: bzrlib/builtins.py:5329
+#: bzrlib/builtins.py:5296
 msgid "Convert the current checkout into a regular branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5331
+#: bzrlib/builtins.py:5298
 msgid ""
 "After unbinding, the local branch is considered independent and subsequent\n"
 "commits will be local only."
 msgstr ""
 
-#: bzrlib/builtins.py:5342
+#: bzrlib/builtins.py:5309
 msgid "Local branch is not bound"
 msgstr ""
 
-#: bzrlib/builtins.py:5346
+#: bzrlib/builtins.py:5313
 msgid "Remove the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5348
+#: bzrlib/builtins.py:5315
 msgid ""
 "--verbose will print out what is being removed.\n"
 "--dry-run will go through all the motions, but not actually\n"
 "remove anything."
 msgstr ""
 
-#: bzrlib/builtins.py:5352
+#: bzrlib/builtins.py:5319
 msgid ""
 "If --revision is specified, uncommit revisions to leave the branch at the\n"
 "specified revision.  For example, \"bzr uncommit -r 15\" will leave the\n"
 "branch at revision 15."
 msgstr ""
 
-#: bzrlib/builtins.py:5356
+#: bzrlib/builtins.py:5323
 msgid ""
 "Uncommit leaves the working tree ready for a new commit.  The only change\n"
 "it may make is to restore any pending merges that were present before\n"
@@ -3378,75 +3365,75 @@
 msgstr ""
 
 # help of 'dry-run' option of 'uncommit' command
-#: bzrlib/builtins.py:5367
+#: bzrlib/builtins.py:5334
 msgid "Don't actually make changes."
 msgstr ""
 
 # help of 'force' option of 'uncommit' command
-#: bzrlib/builtins.py:5368
+#: bzrlib/builtins.py:5335
 msgid "Say yes to all questions."
 msgstr ""
 
 # help of 'keep-tags' option of 'uncommit' command
-#: bzrlib/builtins.py:5370
+#: bzrlib/builtins.py:5337
 msgid "Keep tags that point to removed revisions."
 msgstr ""
 
 # help of 'local' option of 'uncommit' command
-#: bzrlib/builtins.py:5372
+#: bzrlib/builtins.py:5339
 msgid "Only remove the commits from the local branch when in a checkout."
 msgstr ""
 
-#: bzrlib/builtins.py:5421
+#: bzrlib/builtins.py:5388
 msgid "No revisions to uncommit.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5436
+#: bzrlib/builtins.py:5403
 msgid "Dry-run, pretending to remove the above revisions.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5439
+#: bzrlib/builtins.py:5406
 msgid "The above revision(s) will be removed.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5443
+#: bzrlib/builtins.py:5410
 msgid "Uncommit these revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:5446
+#: bzrlib/builtins.py:5413
 msgid "Canceled\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5453
+#: bzrlib/builtins.py:5420
 #, python-format
 msgid ""
 "You can restore the old tip by running:\n"
 "  bzr pull . -r revid:%s\n"
 msgstr ""
 
-#: bzrlib/builtins.py:5458
+#: bzrlib/builtins.py:5425
 msgid "Break a dead lock."
 msgstr ""
 
-#: bzrlib/builtins.py:5460
+#: bzrlib/builtins.py:5427
 msgid ""
 "This command breaks a lock on a repository, branch, working directory or\n"
 "config file."
 msgstr ""
 
-#: bzrlib/builtins.py:5463
+#: bzrlib/builtins.py:5430
 msgid ""
 "CAUTION: Locks should only be broken when you are sure that the process\n"
 "holding the lock has been stopped."
 msgstr ""
 
-#: bzrlib/builtins.py:5466
+#: bzrlib/builtins.py:5433
 msgid ""
 "You can get information on what locks are open via the 'bzr info\n"
 "[location]' command."
 msgstr ""
 
-#: bzrlib/builtins.py:5469
+#: bzrlib/builtins.py:5436
 msgid ""
 ":Examples:\n"
 "    bzr break-lock\n"
@@ -3455,46 +3442,46 @@
 msgstr ""
 
 # help of 'config' option of 'break-lock' command
-#: bzrlib/builtins.py:5478
+#: bzrlib/builtins.py:5445
 msgid "LOCATION is the directory where the config lock is."
 msgstr ""
 
 # help of 'force' option of 'break-lock' command
-#: bzrlib/builtins.py:5480
+#: bzrlib/builtins.py:5447
 msgid "Do not ask for confirmation before breaking the lock."
 msgstr ""
 
 # help of 'protocol=bzr' option of 'serve' command
-#: bzrlib/builtins.py:5515
+#: bzrlib/builtins.py:5482
 msgid "The Bazaar smart server protocol over TCP. (default port: 4155)"
 msgstr ""
 
-#: bzrlib/builtins.py:5516
+#: bzrlib/builtins.py:5483
 msgid "Run the bzr server."
 msgstr ""
 
 # help of 'inet' option of 'serve' command
-#: bzrlib/builtins.py:5522
+#: bzrlib/builtins.py:5489
 msgid "Serve on stdin/out for use from inetd or sshd."
 msgstr ""
 
 # title of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5523
+#: bzrlib/builtins.py:5490
 msgid "protocol"
 msgstr ""
 
 # help of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5524
+#: bzrlib/builtins.py:5491
 msgid "Protocol to serve."
 msgstr ""
 
 # help of 'listen' option of 'serve' command
-#: bzrlib/builtins.py:5528
+#: bzrlib/builtins.py:5495
 msgid "Listen for connections on nominated address."
 msgstr ""
 
 # help of 'port' option of 'serve' command
-#: bzrlib/builtins.py:5530
+#: bzrlib/builtins.py:5497
 msgid ""
 "Listen for connections on nominated port.  Passing 0 as the port number will "
 "result in a dynamically allocated port.  The default port depends on the "
@@ -3502,12 +3489,12 @@
 msgstr ""
 
 # help of 'directory' option of 'serve' command
-#: bzrlib/builtins.py:5535
+#: bzrlib/builtins.py:5502
 msgid "Serve contents of this directory."
 msgstr ""
 
 # help of 'allow-writes' option of 'serve' command
-#: bzrlib/builtins.py:5537
+#: bzrlib/builtins.py:5504
 msgid ""
 "By default the server is a readonly server.  Supplying --allow-writes "
 "enables write access to the contents of the served directory and below.  "
@@ -3517,114 +3504,114 @@
 msgstr ""
 
 # help of 'client-timeout' option of 'serve' command
-#: bzrlib/builtins.py:5546
+#: bzrlib/builtins.py:5513
 msgid "Override the default idle client timeout (5min)."
 msgstr ""
 
-#: bzrlib/builtins.py:5564
+#: bzrlib/builtins.py:5531
 msgid "Combine a tree into its containing tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5566
+#: bzrlib/builtins.py:5533
 msgid "This command requires the target tree to be in a rich-root format."
 msgstr ""
 
-#: bzrlib/builtins.py:5568
+#: bzrlib/builtins.py:5535
 msgid ""
 "The TREE argument should be an independent tree, inside another tree, but\n"
 "not part of it.  (Such trees can be produced by \"bzr split\", but also by\n"
 "running \"bzr branch\" with the target inside a tree.)"
 msgstr ""
 
-#: bzrlib/builtins.py:5572
+#: bzrlib/builtins.py:5539
 msgid ""
 "The result is a combined tree, with the subtree no longer an independent\n"
 "part.  This is marked as a merge of the subtree into the containing tree,\n"
 "and all history is preserved."
 msgstr ""
 
-#: bzrlib/builtins.py:5590
+#: bzrlib/builtins.py:5557
 #, python-format
 msgid ""
 "Can't join trees because %s doesn't support rich root data.\n"
 "You can use bzr upgrade on the repository."
 msgstr ""
 
-#: bzrlib/builtins.py:5600 bzrlib/builtins.py:5606
+#: bzrlib/builtins.py:5567 bzrlib/builtins.py:5573
 msgid "Cannot join {0}.  {1}"
 msgstr ""
 
-#: bzrlib/builtins.py:5610
+#: bzrlib/builtins.py:5577
 msgid "Split a subdirectory of a tree into a separate tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5612
+#: bzrlib/builtins.py:5579
 msgid ""
 "This command will produce a target tree in a format that supports\n"
 "rich roots, like 'rich-root' or 'rich-root-pack'.  These formats cannot be\n"
 "converted into earlier formats like 'dirstate-tags'."
 msgstr ""
 
-#: bzrlib/builtins.py:5616
+#: bzrlib/builtins.py:5583
 msgid ""
 "The TREE argument should be a subdirectory of a working tree.  That\n"
 "subdirectory will be converted into an independent tree, with its own\n"
 "branch.  Commits in the top-level tree will not apply to the new subtree."
 msgstr ""
 
-#: bzrlib/builtins.py:5696
+#: bzrlib/builtins.py:5663
 msgid "No submit branch specified or known"
 msgstr ""
 
-#: bzrlib/builtins.py:5705 bzrlib/send.py:109
+#: bzrlib/builtins.py:5672 bzrlib/send.py:109
 msgid "No public branch specified or known"
 msgstr ""
 
-#: bzrlib/builtins.py:5710
+#: bzrlib/builtins.py:5677
 msgid "bzr merge-directive takes at most two one revision identifiers"
 msgstr ""
 
-#: bzrlib/builtins.py:5719
+#: bzrlib/builtins.py:5686
 msgid "No revisions to bundle."
 msgstr ""
 
-#: bzrlib/builtins.py:5738
+#: bzrlib/builtins.py:5705
 msgid "Mail or create a merge-directive for submitting changes."
 msgstr ""
 
-#: bzrlib/builtins.py:5740
+#: bzrlib/builtins.py:5707
 msgid "A merge directive provides many things needed for requesting merges:"
 msgstr ""
 
-#: bzrlib/builtins.py:5742
+#: bzrlib/builtins.py:5709
 msgid "* A machine-readable description of the merge to perform"
 msgstr ""
 
-#: bzrlib/builtins.py:5744
+#: bzrlib/builtins.py:5711
 msgid "* An optional patch that is a preview of the changes requested"
 msgstr ""
 
-#: bzrlib/builtins.py:5746
+#: bzrlib/builtins.py:5713
 msgid ""
 "* An optional bundle of revision data, so that the changes can be applied\n"
 "  directly from the merge directive, without retrieving data from a\n"
 "  branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5750
+#: bzrlib/builtins.py:5717
 msgid ""
 "`bzr send` creates a compact data set that, when applied using bzr\n"
 "merge, has the same effect as merging from the source branch.  "
 msgstr ""
 
-#: bzrlib/builtins.py:5753
+#: bzrlib/builtins.py:5720
 msgid ""
 "By default the merge directive is self-contained and can be applied to any\n"
 "branch containing submit_branch in its ancestory without needing access to\n"
 "the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5757
+#: bzrlib/builtins.py:5724
 msgid ""
 "If --no-bundle is specified, then Bazaar doesn't send the contents of the\n"
 "revisions, but only a structured request to merge from the\n"
@@ -3633,7 +3620,7 @@
 "included if known, so that people can check it later."
 msgstr ""
 
-#: bzrlib/builtins.py:5763
+#: bzrlib/builtins.py:5730
 msgid ""
 "The submit branch defaults to the parent of the source branch, but can be\n"
 "overridden.  Both submit branch and public branch will be remembered in\n"
@@ -3642,7 +3629,7 @@
 "be changed using --from."
 msgstr ""
 
-#: bzrlib/builtins.py:5769
+#: bzrlib/builtins.py:5736
 msgid ""
 "Both the submit branch and the public branch follow the usual behavior with\n"
 "respect to --remember: If there is no default location set, the first send\n"
@@ -3651,7 +3638,7 @@
 "--remember. The value will only be saved if the location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:5775
+#: bzrlib/builtins.py:5742
 msgid ""
 "In order to calculate those changes, bzr must analyse the submit branch.\n"
 "Therefore it is most efficient for the submit branch to be a local mirror.\n"
@@ -3659,20 +3646,20 @@
 "in the merge directive."
 msgstr ""
 
-#: bzrlib/builtins.py:5780
+#: bzrlib/builtins.py:5747
 msgid ""
 "The default behaviour is to send the merge directive by mail, unless -o is\n"
 "given, in which case it is sent to a file."
 msgstr ""
 
-#: bzrlib/builtins.py:5783
+#: bzrlib/builtins.py:5750
 msgid ""
 "Mail is sent using your preferred mail program.  This should be transparent\n"
 "on Windows (it uses MAPI).  On Unix, it requires the xdg-email utility.\n"
 "If the preferred client can't be found (or used), your editor will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:5787
+#: bzrlib/builtins.py:5754
 msgid ""
 "To use a specific mail program, set the mail_client configuration option.\n"
 "(For Thunderbird 1.5, this works around some bugs.)  Supported values for\n"
@@ -3684,7 +3671,7 @@
 "supported clients."
 msgstr ""
 
-#: bzrlib/builtins.py:5794
+#: bzrlib/builtins.py:5761
 msgid ""
 "If mail is being sent, a to address is required.  This can be supplied\n"
 "either on the commandline, by setting the submit_to configuration\n"
@@ -3692,7 +3679,7 @@
 "in the submit branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5799
+#: bzrlib/builtins.py:5766
 msgid ""
 "Two formats are currently supported: \"4\" uses revision bundle format 4 "
 "and\n"
@@ -3702,13 +3689,13 @@
 "format 1.  It is compatible with Bazaar 0.12 - 0.18."
 msgstr ""
 
-#: bzrlib/builtins.py:5805
+#: bzrlib/builtins.py:5772
 msgid ""
 "The merge directives created by bzr send may be applied using bzr merge or\n"
 "bzr pull by specifying a file containing a merge directive as the location."
 msgstr ""
 
-#: bzrlib/builtins.py:5808
+#: bzrlib/builtins.py:5775
 msgid ""
 "bzr send makes extensive use of public locations to map local locations "
 "into\n"
@@ -3717,44 +3704,44 @@
 msgstr ""
 
 # help of 'output' option of 'send' command
-#: bzrlib/builtins.py:5832
+#: bzrlib/builtins.py:5799
 msgid "Write merge directive to this file or directory; use - for stdout."
 msgstr ""
 
 # help of 'strict' option of 'send' command
-#: bzrlib/builtins.py:5836
+#: bzrlib/builtins.py:5803
 msgid ""
 "Refuse to send if there are uncommitted changes in the working tree, --no-"
 "strict disables the check."
 msgstr ""
 
 # help of 'mail-to' option of 'send' command
-#: bzrlib/builtins.py:5838
+#: bzrlib/builtins.py:5805
 msgid "Mail the request to this address."
 msgstr ""
 
 # help of 'body' option of 'send' command
-#: bzrlib/builtins.py:5842
+#: bzrlib/builtins.py:5809
 msgid "Body for the email."
 msgstr ""
 
 # help of 'no-bundle' option of 'send' command
-#: bzrlib/builtins.py:5895
+#: bzrlib/builtins.py:5862
 msgid "Do not include a bundle in the merge directive."
 msgstr ""
 
 # help of 'no-patch' option of 'send' command
-#: bzrlib/builtins.py:5896
+#: bzrlib/builtins.py:5863
 msgid "Do not include a preview patch in the merge directive."
 msgstr ""
 
 # help of 'remember' option of 'send' command
-#: bzrlib/builtins.py:5899
+#: bzrlib/builtins.py:5866
 msgid "Remember submit and public branch."
 msgstr ""
 
 # help of 'from' option of 'send' command
-#: bzrlib/builtins.py:5901
+#: bzrlib/builtins.py:5868
 msgid ""
 "Branch to generate the submission from, rather than the one containing the "
 "working directory."
@@ -3762,46 +3749,46 @@
 
 # title of 'format' option of 'send' command
 # title of 'format' option of 'version-info' command
-#: bzrlib/builtins.py:5911 bzrlib/cmd_version_info.py:76
+#: bzrlib/builtins.py:5878 bzrlib/cmd_version_info.py:76
 msgid "format"
 msgstr ""
 
 # help of 'format' option of 'send' command
-#: bzrlib/builtins.py:5912
+#: bzrlib/builtins.py:5879
 msgid "Use the specified output format."
 msgstr ""
 
-#: bzrlib/builtins.py:5934
+#: bzrlib/builtins.py:5901
 msgid "Create, remove or modify a tag naming a revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5936
+#: bzrlib/builtins.py:5903
 msgid ""
 "Tags give human-meaningful names to revisions.  Commands that take a -r\n"
 "(--revision) option can be given -rtag:X, where X is any previously\n"
 "created tag."
 msgstr ""
 
-#: bzrlib/builtins.py:5940
+#: bzrlib/builtins.py:5907
 msgid ""
 "Tags are stored in the branch.  Tags are copied from one branch to another\n"
 "along when you branch, push, pull or merge."
 msgstr ""
 
-#: bzrlib/builtins.py:5943
+#: bzrlib/builtins.py:5910
 msgid ""
 "It is an error to give a tag name that already exists unless you pass\n"
 "--force, in which case the tag is moved to point to the new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5946
+#: bzrlib/builtins.py:5913
 msgid ""
 "To rename a tag (change the name but keep it on the same revsion), run "
 "``bzr\n"
 "tag new-name -r tag:old-name`` and then ``bzr tag --delete oldname``."
 msgstr ""
 
-#: bzrlib/builtins.py:5949
+#: bzrlib/builtins.py:5916
 msgid ""
 "If no tag name is specified it will be determined through the \n"
 "'automatic_tag_name' hook. This can e.g. be used to automatically tag\n"
@@ -3810,81 +3797,81 @@
 msgstr ""
 
 # help of 'delete' option of 'tag' command
-#: bzrlib/builtins.py:5959
+#: bzrlib/builtins.py:5926
 msgid "Delete this tag rather than placing it."
 msgstr ""
 
 # help of 'directory' option of 'tag' command
-#: bzrlib/builtins.py:5962
+#: bzrlib/builtins.py:5929
 msgid "Branch in which to place the tag."
 msgstr ""
 
 # help of 'force' option of 'tag' command
-#: bzrlib/builtins.py:5964
+#: bzrlib/builtins.py:5931
 msgid "Replace existing tags."
 msgstr ""
 
-#: bzrlib/builtins.py:5979
+#: bzrlib/builtins.py:5946
 msgid "No tag specified to delete."
 msgstr ""
 
-#: bzrlib/builtins.py:5981
+#: bzrlib/builtins.py:5948
 #, python-format
 msgid "Deleted tag %s."
 msgstr ""
 
-#: bzrlib/builtins.py:5995
+#: bzrlib/builtins.py:5962
 msgid "Please specify a tag name."
 msgstr ""
 
-#: bzrlib/builtins.py:6003
+#: bzrlib/builtins.py:5970
 #, python-format
 msgid "Tag %s already exists for that revision."
 msgstr ""
 
-#: bzrlib/builtins.py:6007
+#: bzrlib/builtins.py:5974
 #, python-format
 msgid "Created tag %s."
 msgstr ""
 
-#: bzrlib/builtins.py:6009
+#: bzrlib/builtins.py:5976
 #, python-format
 msgid "Updated tag %s."
 msgstr ""
 
-#: bzrlib/builtins.py:6013
+#: bzrlib/builtins.py:5980
 msgid "List tags."
 msgstr ""
 
-#: bzrlib/builtins.py:6015
+#: bzrlib/builtins.py:5982
 msgid ""
 "This command shows a table of tag names and the revisions they reference."
 msgstr ""
 
 # help of 'directory' option of 'tags' command
-#: bzrlib/builtins.py:6021
+#: bzrlib/builtins.py:5988
 msgid "Branch whose tags should be displayed."
 msgstr ""
 
 # help of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:6023
+#: bzrlib/builtins.py:5990
 msgid "Sort tags by different criteria."
 msgstr ""
 
 # title of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:6023
+#: bzrlib/builtins.py:5990
 msgid "Sorting"
 msgstr ""
 
-#: bzrlib/builtins.py:6092
+#: bzrlib/builtins.py:6059
 msgid "Reconfigure the type of a bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:6094
+#: bzrlib/builtins.py:6061
 msgid "A target configuration must be specified."
 msgstr ""
 
-#: bzrlib/builtins.py:6096
+#: bzrlib/builtins.py:6063
 msgid ""
 "For checkouts, the bind-to location will be auto-detected if not specified.\n"
 "The order of preference is\n"
@@ -3896,112 +3883,112 @@
 msgstr ""
 
 # title of 'tree_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:6110
+#: bzrlib/builtins.py:6077
 msgid "Tree type"
 msgstr ""
 
 # help of 'tree_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:6111
+#: bzrlib/builtins.py:6078
 msgid "The relation between branch and tree."
 msgstr ""
 
 # help of 'tree_type=branch' option of 'reconfigure' command
-#: bzrlib/builtins.py:6113
+#: bzrlib/builtins.py:6080
 msgid "Reconfigure to be an unbound branch with no working tree."
 msgstr ""
 
 # help of 'tree_type=tree' option of 'reconfigure' command
-#: bzrlib/builtins.py:6114
+#: bzrlib/builtins.py:6081
 msgid "Reconfigure to be an unbound branch with a working tree."
 msgstr ""
 
 # help of 'tree_type=checkout' option of 'reconfigure' command
-#: bzrlib/builtins.py:6115
+#: bzrlib/builtins.py:6082
 msgid "Reconfigure to be a bound branch with a working tree."
 msgstr ""
 
 # help of 'tree_type=lightweight-checkout' option of 'reconfigure' command
-#: bzrlib/builtins.py:6116
+#: bzrlib/builtins.py:6083
 msgid "Reconfigure to be a lightweight checkout (with no local history)."
 msgstr ""
 
 # title of 'repository_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:6121
+#: bzrlib/builtins.py:6088
 msgid "Repository type"
 msgstr ""
 
 # help of 'repository_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:6122
+#: bzrlib/builtins.py:6089
 msgid "Location fo the repository."
 msgstr ""
 
 # help of 'repository_type=standalone' option of 'reconfigure' command
-#: bzrlib/builtins.py:6124
+#: bzrlib/builtins.py:6091
 msgid ""
 "Reconfigure to be a standalone branch (i.e. stop using shared repository)."
 msgstr ""
 
 # help of 'repository_type=use-shared' option of 'reconfigure' command
-#: bzrlib/builtins.py:6126
+#: bzrlib/builtins.py:6093
 msgid "Reconfigure to use a shared repository."
 msgstr ""
 
 # title of 'repository_trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:6130
+#: bzrlib/builtins.py:6097
 msgid "Trees in Repository"
 msgstr ""
 
 # help of 'repository_trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:6131
+#: bzrlib/builtins.py:6098
 msgid "Whether new branches in the repository have trees."
 msgstr ""
 
 # help of 'repository_trees=with-trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:6133
+#: bzrlib/builtins.py:6100
 msgid "Reconfigure repository to create working trees on branches by default."
 msgstr ""
 
 # help of 'repository_trees=with-no-trees' option of 'reconfigure' command
-#: bzrlib/builtins.py:6135
+#: bzrlib/builtins.py:6102
 msgid ""
 "Reconfigure repository to not create working trees on branches by default."
 msgstr ""
 
 # help of 'bind-to' option of 'reconfigure' command
-#: bzrlib/builtins.py:6138
+#: bzrlib/builtins.py:6105
 msgid "Branch to bind checkout to."
 msgstr ""
 
 # help of 'force' option of 'reconfigure' command
-#: bzrlib/builtins.py:6140
+#: bzrlib/builtins.py:6107
 msgid "Perform reconfiguration even if local changes will be lost."
 msgstr ""
 
 # help of 'stacked-on' option of 'reconfigure' command
-#: bzrlib/builtins.py:6143
+#: bzrlib/builtins.py:6110
 msgid "Reconfigure a branch to be stacked on another branch."
 msgstr ""
 
 # help of 'unstacked' option of 'reconfigure' command
-#: bzrlib/builtins.py:6147
+#: bzrlib/builtins.py:6114
 msgid ""
 "Reconfigure a branch to be unstacked.  This may require copying substantial "
 "data into it."
 msgstr ""
 
-#: bzrlib/builtins.py:6157
+#: bzrlib/builtins.py:6124
 msgid "Can't use both --stacked-on and --unstacked"
 msgstr ""
 
-#: bzrlib/builtins.py:6171
+#: bzrlib/builtins.py:6138
 msgid "No target configuration specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6206
+#: bzrlib/builtins.py:6173
 msgid "Set the branch of a checkout and update."
 msgstr ""
 
-#: bzrlib/builtins.py:6208
+#: bzrlib/builtins.py:6175
 msgid ""
 "For lightweight checkouts, this changes the branch being referenced.\n"
 "For heavyweight checkouts, this checks that there are no local commits\n"
@@ -4009,17 +3996,17 @@
 "of the new location and binds to it."
 msgstr ""
 
-#: bzrlib/builtins.py:6213
+#: bzrlib/builtins.py:6180
 msgid ""
 "In both cases, the working tree is updated and uncommitted changes\n"
 "are merged. The user can commit or revert these as they desire."
 msgstr ""
 
-#: bzrlib/builtins.py:6216
+#: bzrlib/builtins.py:6183
 msgid "Pending merges need to be committed or reverted before using switch."
 msgstr ""
 
-#: bzrlib/builtins.py:6218
+#: bzrlib/builtins.py:6185
 msgid ""
 "The path to the branch to switch to can be specified relative to the parent\n"
 "directory of the current branch. For example, if you are currently in a\n"
@@ -4027,7 +4014,7 @@
 "/path/to/newbranch."
 msgstr ""
 
-#: bzrlib/builtins.py:6223
+#: bzrlib/builtins.py:6190
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case switching will update the local nickname to be\n"
@@ -4035,28 +4022,28 @@
 msgstr ""
 
 # help of 'force' option of 'switch' command
-#: bzrlib/builtins.py:6231
+#: bzrlib/builtins.py:6198
 msgid "Switch even if local commits will be lost."
 msgstr ""
 
 # help of 'create-branch' option of 'switch' command
-#: bzrlib/builtins.py:6234
+#: bzrlib/builtins.py:6201
 msgid "Create the target branch from this one before switching to it."
 msgstr ""
 
-#: bzrlib/builtins.py:6248
+#: bzrlib/builtins.py:6215
 msgid "You must supply either a revision or a location"
 msgstr ""
 
-#: bzrlib/builtins.py:6261
+#: bzrlib/builtins.py:6228
 msgid "cannot create branch without source branch"
 msgstr ""
 
-#: bzrlib/builtins.py:6286
+#: bzrlib/builtins.py:6253
 msgid "Manage filtered views."
 msgstr ""
 
-#: bzrlib/builtins.py:6288
+#: bzrlib/builtins.py:6255
 msgid ""
 "Views provide a mask over the tree so that users can focus on\n"
 "a subset of a tree when doing their work. After creating a view,\n"
@@ -4066,7 +4053,7 @@
 "must be within the current view."
 msgstr ""
 
-#: bzrlib/builtins.py:6295
+#: bzrlib/builtins.py:6262
 msgid ""
 "In most cases, a view has a short life-span: it is created to make\n"
 "a selected change and is deleted once that change is committed.\n"
@@ -4074,7 +4061,7 @@
 "and switch between them."
 msgstr ""
 
-#: bzrlib/builtins.py:6300
+#: bzrlib/builtins.py:6267
 msgid ""
 "To disable the current view without deleting it, you can switch to\n"
 "the pseudo view called ``off``. This can be useful when you need\n"
@@ -4082,211 +4069,211 @@
 "want to switch back to your view after that."
 msgstr ""
 
-#: bzrlib/builtins.py:6305
+#: bzrlib/builtins.py:6272
 msgid ""
 ":Examples:\n"
 "  To define the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6308
+#: bzrlib/builtins.py:6275
 msgid "    bzr view file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:6310
+#: bzrlib/builtins.py:6277
 msgid "  To list the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6312
+#: bzrlib/builtins.py:6279
 msgid "    bzr view"
 msgstr ""
 
-#: bzrlib/builtins.py:6314
+#: bzrlib/builtins.py:6281
 msgid "  To delete the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6316
+#: bzrlib/builtins.py:6283
 msgid "    bzr view --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:6318
+#: bzrlib/builtins.py:6285
 msgid "  To disable the current view without deleting it::"
 msgstr ""
 
-#: bzrlib/builtins.py:6320
+#: bzrlib/builtins.py:6287
 msgid "    bzr view --switch off"
 msgstr ""
 
-#: bzrlib/builtins.py:6322
+#: bzrlib/builtins.py:6289
 msgid "  To define a named view and switch to it::"
 msgstr ""
 
-#: bzrlib/builtins.py:6324
+#: bzrlib/builtins.py:6291
 msgid "    bzr view --name view-name file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:6326
+#: bzrlib/builtins.py:6293
 msgid "  To list a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6328
+#: bzrlib/builtins.py:6295
 msgid "    bzr view --name view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:6330
+#: bzrlib/builtins.py:6297
 msgid "  To delete a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6332
+#: bzrlib/builtins.py:6299
 msgid "    bzr view --name view-name --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:6334
+#: bzrlib/builtins.py:6301
 msgid "  To switch to a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:6336
+#: bzrlib/builtins.py:6303
 msgid "    bzr view --switch view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:6338
+#: bzrlib/builtins.py:6305
 msgid "  To list all views defined::"
 msgstr ""
 
-#: bzrlib/builtins.py:6340
+#: bzrlib/builtins.py:6307
 msgid "    bzr view --all"
 msgstr ""
 
-#: bzrlib/builtins.py:6342
+#: bzrlib/builtins.py:6309
 msgid "  To delete all views::"
 msgstr ""
 
-#: bzrlib/builtins.py:6344
+#: bzrlib/builtins.py:6311
 msgid "    bzr view --delete --all"
 msgstr ""
 
 # help of 'all' option of 'view' command
-#: bzrlib/builtins.py:6351
+#: bzrlib/builtins.py:6318
 msgid "Apply list or delete action to all views."
 msgstr ""
 
 # help of 'delete' option of 'view' command
-#: bzrlib/builtins.py:6354
+#: bzrlib/builtins.py:6321
 msgid "Delete the view."
 msgstr ""
 
 # help of 'name' option of 'view' command
-#: bzrlib/builtins.py:6357
+#: bzrlib/builtins.py:6324
 msgid "Name of the view to define, list or delete."
 msgstr ""
 
 # help of 'switch' option of 'view' command
-#: bzrlib/builtins.py:6361
+#: bzrlib/builtins.py:6328
 msgid "Name of the view to switch to."
 msgstr ""
 
-#: bzrlib/builtins.py:6380
+#: bzrlib/builtins.py:6347
 msgid "Both --delete and a file list specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6383
+#: bzrlib/builtins.py:6350
 msgid "Both --delete and --switch specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6386
+#: bzrlib/builtins.py:6353
 msgid "Deleted all views.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6388
+#: bzrlib/builtins.py:6355
 msgid "No current view to delete"
 msgstr ""
 
-#: bzrlib/builtins.py:6391
+#: bzrlib/builtins.py:6358
 #, python-format
 msgid "Deleted '%s' view.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6395
+#: bzrlib/builtins.py:6362
 msgid "Both --switch and a file list specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6398
+#: bzrlib/builtins.py:6365
 msgid "Both --switch and --all specified"
 msgstr ""
 
-#: bzrlib/builtins.py:6401
+#: bzrlib/builtins.py:6368
 msgid "No current view to disable"
 msgstr ""
 
-#: bzrlib/builtins.py:6403
+#: bzrlib/builtins.py:6370
 #, python-format
 msgid "Disabled '%s' view.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6407 bzrlib/builtins.py:6429
+#: bzrlib/builtins.py:6374 bzrlib/builtins.py:6396
 msgid "Using '{0}' view: {1}\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6410
+#: bzrlib/builtins.py:6377
 msgid "Views defined:\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6419
+#: bzrlib/builtins.py:6386
 msgid "No views defined.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6426
+#: bzrlib/builtins.py:6393
 msgid "Cannot change the 'off' pseudo view"
 msgstr ""
 
-#: bzrlib/builtins.py:6434
+#: bzrlib/builtins.py:6401
 msgid "No current view.\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6437
+#: bzrlib/builtins.py:6404
 msgid "'{0}' view is: {1}\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6457
+#: bzrlib/builtins.py:6424
 msgid "    <no hooks installed>\n"
 msgstr ""
 
-#: bzrlib/builtins.py:6461
+#: bzrlib/builtins.py:6428
 msgid "Remove a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:6463
+#: bzrlib/builtins.py:6430
 msgid ""
 "This will remove the branch from the specified location but \n"
 "will keep any working tree or repository in place."
 msgstr ""
 
-#: bzrlib/builtins.py:6468
+#: bzrlib/builtins.py:6435
 msgid "  Remove the branch at repo/trunk::"
 msgstr ""
 
-#: bzrlib/builtins.py:6470
+#: bzrlib/builtins.py:6437
 msgid "    bzr remove-branch repo/trunk"
 msgstr ""
 
 # help of 'force' option of 'remove-branch' command
-#: bzrlib/builtins.py:6477
+#: bzrlib/builtins.py:6444
 msgid "Remove branch even if it is the active branch."
 msgstr ""
 
-#: bzrlib/builtins.py:6491
+#: bzrlib/builtins.py:6458
 msgid "Branch is active. Use --force to remove it."
 msgstr ""
 
 # help of 'writer=plain' option of 'shelve' command
-#: bzrlib/builtins.py:6495
+#: bzrlib/builtins.py:6462
 msgid "Plaintext diff output."
 msgstr ""
 
-#: bzrlib/builtins.py:6496
+#: bzrlib/builtins.py:6463
 msgid "Temporarily set aside some changes from the current tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6498
+#: bzrlib/builtins.py:6465
 msgid ""
 "Shelve allows you to temporarily put changes you've made \"on the shelf\",\n"
 "ie. out of the way, until a later time when you can bring them back from\n"
@@ -4295,11 +4282,11 @@
 "will they survive its deletion."
 msgstr ""
 
-#: bzrlib/builtins.py:6504
+#: bzrlib/builtins.py:6471
 msgid "If shelve --list is specified, previously-shelved changes are listed."
 msgstr ""
 
-#: bzrlib/builtins.py:6506
+#: bzrlib/builtins.py:6473
 msgid ""
 "Shelve is intended to help separate several sets of changes that have\n"
 "been inappropriately mingled.  If you just want to get rid of all changes\n"
@@ -4307,35 +4294,35 @@
 "shelve all text changes at once, use shelve --all."
 msgstr ""
 
-#: bzrlib/builtins.py:6511
+#: bzrlib/builtins.py:6478
 msgid ""
 "If filenames are specified, only the changes to those files will be\n"
 "shelved. Other files will be left untouched."
 msgstr ""
 
-#: bzrlib/builtins.py:6514
+#: bzrlib/builtins.py:6481
 msgid ""
 "If a revision is specified, changes since that revision will be shelved."
 msgstr ""
 
-#: bzrlib/builtins.py:6516
+#: bzrlib/builtins.py:6483
 msgid ""
 "You can put multiple items on the shelf, and by default, 'unshelve' will\n"
 "restore the most recently shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6519
+#: bzrlib/builtins.py:6486
 msgid ""
 "For complicated changes, it is possible to edit the changes in a separate\n"
 "editor program to decide what the file remaining in the working copy\n"
 "should look like.  To do this, add the configuration option"
 msgstr ""
 
-#: bzrlib/builtins.py:6523
+#: bzrlib/builtins.py:6490
 msgid "    change_editor = PROGRAM @new_path @old_path"
 msgstr ""
 
-#: bzrlib/builtins.py:6525
+#: bzrlib/builtins.py:6492
 msgid ""
 "where @new_path is replaced with the path of the new version of the \n"
 "file and @old_path is replaced with the path of the old version of \n"
@@ -4345,39 +4332,39 @@
 msgstr ""
 
 # help of 'all' option of 'shelve' command
-#: bzrlib/builtins.py:6537
+#: bzrlib/builtins.py:6504
 msgid "Shelve all changes."
 msgstr ""
 
 # help of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6539
+#: bzrlib/builtins.py:6506
 msgid "Method to use for writing diffs."
 msgstr ""
 
 # title of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6539
+#: bzrlib/builtins.py:6506
 msgid "writer"
 msgstr ""
 
 # help of 'list' option of 'shelve' command
-#: bzrlib/builtins.py:6543
+#: bzrlib/builtins.py:6510
 msgid "List shelved changes."
 msgstr ""
 
 # help of 'destroy' option of 'shelve' command
-#: bzrlib/builtins.py:6545
+#: bzrlib/builtins.py:6512
 msgid "Destroy removed changes instead of shelving them."
 msgstr ""
 
-#: bzrlib/builtins.py:6574
+#: bzrlib/builtins.py:6541
 msgid "No shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6585
+#: bzrlib/builtins.py:6552
 msgid "Restore shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6587
+#: bzrlib/builtins.py:6554
 msgid ""
 "By default, the most recently shelved changes are restored. However if you\n"
 "specify a shelf by id those changes will be restored instead.  This works\n"
@@ -4385,93 +4372,93 @@
 msgstr ""
 
 # help of 'action' option of 'unshelve' command
-#: bzrlib/builtins.py:6596
+#: bzrlib/builtins.py:6563
 msgid "The action to perform."
 msgstr ""
 
 # title of 'action' option of 'resolve' command
 # title of 'action' option of 'unshelve' command
-#: bzrlib/builtins.py:6596 bzrlib/conflicts.py:694
+#: bzrlib/builtins.py:6563 bzrlib/conflicts.py:694
 msgid "action"
 msgstr ""
 
 # help of 'action=apply' option of 'unshelve' command
-#: bzrlib/builtins.py:6598
+#: bzrlib/builtins.py:6565
 msgid "Apply changes and remove from the shelf."
 msgstr ""
 
 # help of 'action=dry-run' option of 'unshelve' command
-#: bzrlib/builtins.py:6599
+#: bzrlib/builtins.py:6566
 msgid "Show changes, but do not apply or remove them."
 msgstr ""
 
 # help of 'action=preview' option of 'unshelve' command
-#: bzrlib/builtins.py:6600
+#: bzrlib/builtins.py:6567
 msgid ""
 "Instead of unshelving the changes, show the diff that would result from "
 "unshelving."
 msgstr ""
 
 # help of 'action=delete-only' option of 'unshelve' command
-#: bzrlib/builtins.py:6602
+#: bzrlib/builtins.py:6569
 msgid "Delete changes without applying them."
 msgstr ""
 
 # help of 'action=keep' option of 'unshelve' command
-#: bzrlib/builtins.py:6603
+#: bzrlib/builtins.py:6570
 msgid "Apply changes but don't delete them."
 msgstr ""
 
-#: bzrlib/builtins.py:6618
+#: bzrlib/builtins.py:6585
 msgid "Remove unwanted files from working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6620
+#: bzrlib/builtins.py:6587
 msgid ""
 "By default, only unknown files, not ignored files, are deleted.  Versioned\n"
 "files are never deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:6623
+#: bzrlib/builtins.py:6590
 msgid ""
 "Another class is 'detritus', which includes files emitted by bzr during\n"
 "normal operations and selftests.  (The value of these files decreases with\n"
 "time.)"
 msgstr ""
 
-#: bzrlib/builtins.py:6627
+#: bzrlib/builtins.py:6594
 msgid ""
 "If no options are specified, unknown files are deleted.  Otherwise, option\n"
 "flags are respected, and may be combined."
 msgstr ""
 
-#: bzrlib/builtins.py:6630
+#: bzrlib/builtins.py:6597
 msgid "To check what clean-tree will do, use --dry-run."
 msgstr ""
 
 # help of 'ignored' option of 'clean-tree' command
-#: bzrlib/builtins.py:6633
+#: bzrlib/builtins.py:6600
 msgid "Delete all ignored files."
 msgstr ""
 
 # help of 'detritus' option of 'clean-tree' command
-#: bzrlib/builtins.py:6634
+#: bzrlib/builtins.py:6601
 msgid ""
 "Delete conflict files, merge and revert backups, and failed selftest dirs."
 msgstr ""
 
 # help of 'unknown' option of 'clean-tree' command
-#: bzrlib/builtins.py:6637
+#: bzrlib/builtins.py:6604
 msgid "Delete files unknown to bzr (default)."
 msgstr ""
 
 # help of 'dry-run' option of 'clean-tree' command
-#: bzrlib/builtins.py:6638
+#: bzrlib/builtins.py:6605
 msgid "Show files to delete instead of deleting them."
 msgstr ""
 
 # help of 'force' option of 'clean-tree' command
-#: bzrlib/builtins.py:6640
+#: bzrlib/builtins.py:6607
 msgid "Do not prompt before deleting."
 msgstr ""
 
@@ -4531,35 +4518,35 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/bzrdir.py:487
+#: bzrlib/bzrdir.py:486
 msgid ""
 "making backup of {0}\n"
 "  to {1}"
 msgstr ""
 
-#: bzrlib/bzrdir.py:510
+#: bzrlib/bzrdir.py:509
 msgid "renamed {0} to {1}"
 msgstr ""
 
-#: bzrlib/bzrdir.py:1639
+#: bzrlib/bzrdir.py:1638
 #, python-format
 msgid ""
 "Source repository format does not support stacking, using format:\n"
 "  %s"
 msgstr ""
 
-#: bzrlib/bzrdir.py:1659
+#: bzrlib/bzrdir.py:1658
 #, python-format
 msgid ""
 "Source branch format does not support stacking, using format:\n"
 "  %s"
 msgstr ""
 
-#: bzrlib/bzrdir.py:1805
+#: bzrlib/bzrdir.py:1804
 msgid "starting repository conversion"
 msgstr ""
 
-#: bzrlib/bzrdir.py:2026
+#: bzrlib/bzrdir.py:2025
 msgid "Using default stacking branch {0} at {1}"
 msgstr ""
 
@@ -4745,8 +4732,8 @@
 "supported formats or in a custom format based on a template."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:59 en/help_topics/configuration.txt:712
-#: en/help_topics/configuration.txt:722
+#: bzrlib/cmd_version_info.py:59 en/help_topics/configuration.txt:700
+#: en/help_topics/configuration.txt:710
 msgid "For example::"
 msgstr ""
 
@@ -4997,41 +4984,41 @@
 msgid "Invalid config value for \"{0}\"  value {1!r} is not an SI unit."
 msgstr ""
 
-#: bzrlib/config.py:2452
+#: bzrlib/config.py:2451
 msgid "{0} is not an SI unit."
 msgstr ""
 
-#: bzrlib/config.py:2971
+#: bzrlib/config.py:2970
 msgid ""
 "Option {0} in section {1} of {2} was changed from {3} to {4}. The {5} value "
 "will be saved."
 msgstr ""
 
-#: bzrlib/config.py:3116
+#: bzrlib/config.py:3114
 #, python-format
 msgid "Invalid '%s', should be of the form 'name=value'"
 msgstr ""
 
-#: bzrlib/config.py:4018
+#: bzrlib/config.py:4004
 msgid "Display, set or remove a configuration option."
 msgstr ""
 
-#: bzrlib/config.py:4020
+#: bzrlib/config.py:4006
 msgid "Display the active value for a given option."
 msgstr ""
 
-#: bzrlib/config.py:4022
+#: bzrlib/config.py:4008
 msgid ""
 "If --all is specified, NAME is interpreted as a regular expression and all\n"
 "matching options are displayed mentioning their scope. The active value\n"
 "that bzr will take into account is the first one displayed for each option."
 msgstr ""
 
-#: bzrlib/config.py:4026
+#: bzrlib/config.py:4012
 msgid "If no NAME is given, --all .* is implied."
 msgstr ""
 
-#: bzrlib/config.py:4028
+#: bzrlib/config.py:4014
 msgid ""
 "Setting a value is achieved by using name=value without spaces. The value\n"
 "is set in the most relevant scope and can be checked by displaying the\n"
@@ -5039,17 +5026,17 @@
 msgstr ""
 
 # help of 'scope' option of 'config' command
-#: bzrlib/config.py:4040
+#: bzrlib/config.py:4026
 msgid "Reduce the scope to the specified configuration file."
 msgstr ""
 
 # help of 'all' option of 'config' command
-#: bzrlib/config.py:4044
+#: bzrlib/config.py:4030
 msgid "Display all the defined values for the matching options."
 msgstr ""
 
 # help of 'remove' option of 'config' command
-#: bzrlib/config.py:4046
+#: bzrlib/config.py:4032
 msgid "Remove the option from the configuration file."
 msgstr ""
 
@@ -7347,7 +7334,7 @@
 msgid "bzr: ERROR (ignored): %s"
 msgstr ""
 
-#: bzrlib/remote.py:2534
+#: bzrlib/remote.py:2541
 msgid "Copying repository content as tarball..."
 msgstr ""
 
@@ -7363,23 +7350,23 @@
 msgid "{0} => {1}"
 msgstr ""
 
-#: bzrlib/repository.py:1738
+#: bzrlib/repository.py:1799
 msgid "Moving repository to repository.backup"
 msgstr ""
 
-#: bzrlib/repository.py:1745
+#: bzrlib/repository.py:1806
 msgid "Creating new repository"
 msgstr ""
 
-#: bzrlib/repository.py:1750
+#: bzrlib/repository.py:1811
 msgid "Copying content"
 msgstr ""
 
-#: bzrlib/repository.py:1754
+#: bzrlib/repository.py:1815
 msgid "Deleting old repository content"
 msgstr ""
 
-#: bzrlib/repository.py:1756
+#: bzrlib/repository.py:1817
 msgid "repository converted"
 msgstr ""
 
@@ -7605,15 +7592,15 @@
 msgid "adding file"
 msgstr ""
 
-#: bzrlib/transform.py:2598
+#: bzrlib/transform.py:2590
 msgid "Building tree"
 msgstr ""
 
-#: bzrlib/transform.py:2688 bzrlib/transform.py:2715
+#: bzrlib/transform.py:2680 bzrlib/transform.py:2707
 msgid "Adding file contents"
 msgstr ""
 
-#: bzrlib/transform.py:3017
+#: bzrlib/transform.py:3009
 msgid "Resolution pass"
 msgstr ""
 
@@ -7622,7 +7609,7 @@
 msgid "Authenticated as %s"
 msgstr ""
 
-#: bzrlib/tree.py:647
+#: bzrlib/tree.py:637
 msgid "*** {0} content-filter: {1} => {2!r}"
 msgstr ""
 
@@ -7762,7 +7749,7 @@
 
 #: dummy/help_topics/basic/detail.txt:1
 msgid ""
-"Bazaar 2.6b2 -- a free distributed version-control tool\n"
+"Bazaar 2.6.0dev1 -- a free distributed version-control tool\n"
 "http://bazaar.canonical.com/"
 msgstr ""
 
@@ -8080,6 +8067,50 @@
 msgid "How to fix diverged branches"
 msgstr ""
 
+#: dummy/help_topics/env-variables/detail.txt:1
+msgid "Environment Variables"
+msgstr ""
+
+#: dummy/help_topics/env-variables/detail.txt:3
+msgid ""
+"=================== "
+"===========================================================\n"
+"BZRPATH             Path where bzr is to look for shell plugin external\n"
+"                    commands.\n"
+"BZR_EMAIL           E-Mail address of the user. Overrides EMAIL.\n"
+"EMAIL               E-Mail address of the user.\n"
+"BZR_EDITOR          Editor for editing commit messages. Overrides EDITOR.\n"
+"EDITOR              Editor for editing commit messages.\n"
+"BZR_PLUGIN_PATH     Paths where bzr should look for plugins.\n"
+"BZR_DISABLE_PLUGINS Plugins that bzr should not load.\n"
+"BZR_PLUGINS_AT      Plugins to load from a directory not in "
+"BZR_PLUGIN_PATH.\n"
+"BZR_HOME            Directory holding .bazaar config dir. Overrides HOME.\n"
+"BZR_HOME (Win32)    Directory holding bazaar config dir. Overrides APPDATA "
+"and\n"
+"                    HOME.\n"
+"BZR_REMOTE_PATH     Full name of remote 'bzr' command (for bzr+ssh:// "
+"URLs).\n"
+"BZR_SSH             Path to SSH client, or one of paramiko, openssh, "
+"sshcorp,\n"
+"                    plink or lsh.\n"
+"BZR_LOG             Location of .bzr.log (use '/dev/null' to suppress log).\n"
+"BZR_LOG (Win32)     Location of .bzr.log (use 'NUL' to suppress log).\n"
+"BZR_COLUMNS         Override implicit terminal width.\n"
+"BZR_CONCURRENCY     Number of processes that can be run concurrently "
+"(selftest)\n"
+"BZR_PROGRESS_BAR    Override the progress display. Values are 'none' or "
+"'text'.\n"
+"BZR_PDB             Control whether to launch a debugger on error.\n"
+"BZR_SIGQUIT_PDB     Control whether SIGQUIT behaves normally or invokes a\n"
+"                    breakin debugger.\n"
+"BZR_TEXTUI_INPUT    Force console input mode for prompts to line-based "
+"(instead\n"
+"                    of char-based).\n"
+"=================== "
+"===========================================================\n"
+msgstr ""
+
 #: dummy/help_topics/env-variables/summary.txt:1
 msgid "Environment variable names and values"
 msgstr ""
@@ -9079,7 +9110,7 @@
 msgid "    bzr commit --fixes <tracker>:<id>"
 msgstr ""
 
-#: en/help_topics/bugs.txt:13 en/help_topics/configuration.txt:410
+#: en/help_topics/bugs.txt:13 en/help_topics/configuration.txt:398
 msgid "or::"
 msgstr ""
 
@@ -9313,8 +9344,7 @@
 "remove-tree       Remove the working tree from a given branch/checkout.\n"
 "renames           Show list of renamed files.\n"
 "resolve           Mark a conflict as resolved.\n"
-"revert            Set files in the working tree back to the contents of a\n"
-"                  previous revision.\n"
+"revert            Revert files to a previous revision.\n"
 "revno             Show current revision number.\n"
 "root              Show the tree root directory.\n"
 "send              Mail or create a merge-directive for submitting changes.\n"
@@ -9970,46 +10000,19 @@
 
 #: en/help_topics/configuration.txt:336
 msgid ""
-"Another such option is ``branchname``, which refers to the name of a "
-"colocated\n"
-"branch.  For non-colocated branches, it behaves like basename.  It can be "
-"used\n"
-"like this::"
-msgstr ""
-
-#: en/help_topics/configuration.txt:340
-msgid ""
-"  [/home/vila/src/bzr/bugs]\n"
-"  mypush = lp:~vila/bzr/{branchname}"
-msgstr ""
-
-#: en/help_topics/configuration.txt:343
-msgid ""
-"When used with a colocated branch named ``832013-expand-in-stack``, we'll "
-"get::"
-msgstr ""
-
-#: en/help_topics/configuration.txt:345
-msgid ""
-"  bzr config mypush\n"
-"  lp:~vila/bzr/832013-expand-in-stack"
-msgstr ""
-
-#: en/help_topics/configuration.txt:348
-msgid ""
 "When an option is local to a Section, it cannot be referred to from option\n"
 "values in any other section from the same ``Store`` nor from any other\n"
 "``Store``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:352
+#: en/help_topics/configuration.txt:340
 msgid ""
 "\n"
 "The main configuration file, bazaar.conf\n"
 "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:356
+#: en/help_topics/configuration.txt:344
 msgid ""
 "``bazaar.conf`` allows two sections: ``[DEFAULT]`` and ``[ALIASES]``.\n"
 "The default section contains the default\n"
@@ -10017,11 +10020,11 @@
 "overriden by providing a branch-specific section in ``locations.conf``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:361
+#: en/help_topics/configuration.txt:349
 msgid "A typical ``bazaar.conf`` section often looks like the following::"
 msgstr ""
 
-#: en/help_topics/configuration.txt:363
+#: en/help_topics/configuration.txt:351
 msgid ""
 "    [DEFAULT]\n"
 "    email             = John Doe <jdoe@isp.com>\n"
@@ -10029,14 +10032,14 @@
 "    create_signatures = when-required"
 msgstr ""
 
-#: en/help_topics/configuration.txt:368
+#: en/help_topics/configuration.txt:356
 msgid ""
 "\n"
 "The branch location configuration file, locations.conf\n"
 "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:372
+#: en/help_topics/configuration.txt:360
 msgid ""
 "``locations.conf`` allows one to specify overriding settings for\n"
 "a specific branch. The format is almost identical to the default section in\n"
@@ -10046,25 +10049,25 @@
 "for. The '?' and '*' wildcards are supported::"
 msgstr ""
 
-#: en/help_topics/configuration.txt:378
+#: en/help_topics/configuration.txt:366
 msgid ""
 "    [/home/jdoe/branches/nethack]\n"
 "    email = Nethack Admin <nethack@nethack.com>"
 msgstr ""
 
-#: en/help_topics/configuration.txt:381
+#: en/help_topics/configuration.txt:369
 msgid ""
 "    [http://hypothetical.site.com/branches/devel-branch]\n"
 "    create_signatures = always"
 msgstr ""
 
-#: en/help_topics/configuration.txt:384
+#: en/help_topics/configuration.txt:372
 msgid ""
 "The authentication configuration file, authentication.conf\n"
 "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:387
+#: en/help_topics/configuration.txt:375
 msgid ""
 "``authentication.conf`` allows one to specify credentials for\n"
 "remote servers. This can be used for all the supported transports and any "
@@ -10072,70 +10075,70 @@
 "of bzr that requires authentication (smtp for example)."
 msgstr ""
 
-#: en/help_topics/configuration.txt:391
+#: en/help_topics/configuration.txt:379
 msgid ""
 "The syntax of the file obeys the same rules as the others except for the\n"
 "option policies which don't apply."
 msgstr ""
 
-#: en/help_topics/configuration.txt:394
+#: en/help_topics/configuration.txt:382
 msgid ""
 "For more information on the possible uses of the authentication "
 "configuration\n"
 "file see :doc:`authentication-help`."
 msgstr ""
 
-#: en/help_topics/configuration.txt:397
+#: en/help_topics/configuration.txt:385
 msgid ""
 "\n"
 "Common options\n"
 "--------------"
 msgstr ""
 
-#: en/help_topics/configuration.txt:401
+#: en/help_topics/configuration.txt:389
 msgid ""
 "debug_flags\n"
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:404
+#: en/help_topics/configuration.txt:392
 msgid ""
 "A comma-separated list of debugging options to turn on.  The same values\n"
 "can be used as with the -D command-line option (see `help global-options`).\n"
 "For example::"
 msgstr ""
 
-#: en/help_topics/configuration.txt:408
+#: en/help_topics/configuration.txt:396
 msgid "    debug_flags = hpss"
 msgstr ""
 
-#: en/help_topics/configuration.txt:412
+#: en/help_topics/configuration.txt:400
 msgid "    debug_flags = hpss,evil"
 msgstr ""
 
-#: en/help_topics/configuration.txt:414
+#: en/help_topics/configuration.txt:402
 msgid ""
 "email\n"
 "~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:417
+#: en/help_topics/configuration.txt:405
 msgid ""
 "The email address to use when committing a branch. Typically takes the form\n"
 "of::"
 msgstr ""
 
-#: en/help_topics/configuration.txt:420
+#: en/help_topics/configuration.txt:408
 msgid "    email = Full Name <account@hostname.tld>"
 msgstr ""
 
-#: en/help_topics/configuration.txt:422
+#: en/help_topics/configuration.txt:410
 msgid ""
 "editor\n"
 "~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:425
+#: en/help_topics/configuration.txt:413
 msgid ""
 "The path of the editor that you wish to use if *bzr commit* is run without\n"
 "a commit message. This setting is trumped by the environment variable\n"
@@ -10143,44 +10146,44 @@
 "variables."
 msgstr ""
 
-#: en/help_topics/configuration.txt:430
+#: en/help_topics/configuration.txt:418
 msgid ""
 "log_format\n"
 "~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:433
+#: en/help_topics/configuration.txt:421
 msgid ""
 "The default log format to use. Standard log formats are ``long``, ``short``\n"
 "and ``line``. Additional formats may be provided by plugins. The default\n"
 "value is ``long``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:437
+#: en/help_topics/configuration.txt:425
 msgid ""
 "check_signatures\n"
 "~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:440
+#: en/help_topics/configuration.txt:428
 msgid ""
 "Reserved for future use.  These options will allow a policy for branches to\n"
 "require signatures."
 msgstr ""
 
-#: en/help_topics/configuration.txt:443
+#: en/help_topics/configuration.txt:431
 msgid ""
 "require\n"
 "    The gnupg signature for revisions must be present and must be valid."
 msgstr ""
 
-#: en/help_topics/configuration.txt:446
+#: en/help_topics/configuration.txt:434
 msgid ""
 "ignore\n"
 "    Do not check gnupg signatures of revisions."
 msgstr ""
 
-#: en/help_topics/configuration.txt:449
+#: en/help_topics/configuration.txt:437
 msgid ""
 "check-available\n"
 "    (default) If gnupg signatures for revisions are present, check them.\n"
@@ -10188,20 +10191,20 @@
 "    no signature is present."
 msgstr ""
 
-#: en/help_topics/configuration.txt:454
+#: en/help_topics/configuration.txt:442
 msgid ""
 "create_signatures\n"
 "~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:457
+#: en/help_topics/configuration.txt:445
 msgid ""
 "Defines the behaviour of signing revisions on commits.  By default bzr will "
 "not\n"
 "sign new commits."
 msgstr ""
 
-#: en/help_topics/configuration.txt:460
+#: en/help_topics/configuration.txt:448
 msgid ""
 "always\n"
 "    Sign every new revision that is committed.  If the signing fails then "
@@ -10209,19 +10212,19 @@
 "    commit will not be made."
 msgstr ""
 
-#: en/help_topics/configuration.txt:464
+#: en/help_topics/configuration.txt:452
 msgid ""
 "when-required\n"
 "    Reserved for future use."
 msgstr ""
 
-#: en/help_topics/configuration.txt:467
+#: en/help_topics/configuration.txt:455
 msgid ""
 "never\n"
 "    Reserved for future use."
 msgstr ""
 
-#: en/help_topics/configuration.txt:470
+#: en/help_topics/configuration.txt:458
 msgid ""
 "In future it is planned that ``when-required`` will sign newly\n"
 "committed revisions only when the branch requires them.  ``never`` will "
@@ -10229,123 +10232,123 @@
 "to sign newly committed revisions, even if the branch requires signatures."
 msgstr ""
 
-#: en/help_topics/configuration.txt:474
+#: en/help_topics/configuration.txt:462
 msgid ""
 "dirstate.fdatasync\n"
 "~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:477
+#: en/help_topics/configuration.txt:465
 msgid ""
 "If true (default), working tree metadata changes are flushed through the\n"
 "OS buffers to physical disk.  This is somewhat slower, but means data\n"
 "should not be lost if the machine crashes.  See also repository.fdatasync."
 msgstr ""
 
-#: en/help_topics/configuration.txt:481
+#: en/help_topics/configuration.txt:469
 msgid ""
 "gpg_signing_key\n"
 "~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:484
+#: en/help_topics/configuration.txt:472
 msgid ""
 "The GnuPG user identity to use when signing commits.  Can be an e-mail\n"
 "address, key fingerprint or full key ID.  When unset or when set to\n"
 "\"default\" Bazaar will use the user e-mail set with ``whoami``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:488
+#: en/help_topics/configuration.txt:476
 msgid ""
 "recurse\n"
 "~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:491
+#: en/help_topics/configuration.txt:479
 msgid ""
 "Only useful in ``locations.conf``. Defines whether or not the\n"
 "configuration for this section applies to subdirectories:"
 msgstr ""
 
-#: en/help_topics/configuration.txt:494
+#: en/help_topics/configuration.txt:482
 msgid ""
 "true\n"
 "    (default) This section applies to subdirectories as well."
 msgstr ""
 
-#: en/help_topics/configuration.txt:497
+#: en/help_topics/configuration.txt:485
 msgid ""
 "false\n"
 "    This section only applies to the branch at this directory and not\n"
 "    branches below it."
 msgstr ""
 
-#: en/help_topics/configuration.txt:501
+#: en/help_topics/configuration.txt:489
 msgid ""
 "gpg_signing_command\n"
 "~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:504
+#: en/help_topics/configuration.txt:492
 msgid ""
 "(Default: \"gpg\"). Which program should be used to sign and check "
 "revisions.\n"
 "For example::"
 msgstr ""
 
-#: en/help_topics/configuration.txt:507
+#: en/help_topics/configuration.txt:495
 msgid "    gpg_signing_command = /usr/bin/gnpg"
 msgstr ""
 
-#: en/help_topics/configuration.txt:509
+#: en/help_topics/configuration.txt:497
 msgid ""
 "The specified command must accept the options \"--clearsign\" and \"-u "
 "<email>\"."
 msgstr ""
 
-#: en/help_topics/configuration.txt:511
+#: en/help_topics/configuration.txt:499
 msgid ""
 "bzr_remote_path\n"
 "~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:514
+#: en/help_topics/configuration.txt:502
 msgid ""
 "(Default: \"bzr\").  The path to the command that should be used to run the "
 "smart\n"
 "server for bzr.  This value may only be specified in locations.conf, because:"
 msgstr ""
 
-#: en/help_topics/configuration.txt:517
+#: en/help_topics/configuration.txt:505
 msgid ""
 "- it's needed before branch.conf is accessible\n"
 "- allowing remote branch.conf files to specify commands would be a security\n"
 "  risk"
 msgstr ""
 
-#: en/help_topics/configuration.txt:521
+#: en/help_topics/configuration.txt:509
 msgid "It is overridden by the BZR_REMOTE_PATH environment variable."
 msgstr ""
 
-#: en/help_topics/configuration.txt:523
+#: en/help_topics/configuration.txt:511
 msgid ""
 "smtp_server\n"
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:526
+#: en/help_topics/configuration.txt:514
 msgid ""
 "(Default: \"localhost\"). SMTP server to use when Bazaar needs to send\n"
 "email, eg. with ``merge-directive --mail-to``, or the bzr-email plugin."
 msgstr ""
 
-#: en/help_topics/configuration.txt:529
+#: en/help_topics/configuration.txt:517
 msgid ""
 "smtp_username, smtp_password\n"
 "~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:532
+#: en/help_topics/configuration.txt:520
 msgid ""
 "User and password to authenticate to the SMTP server. If smtp_username\n"
 "is set, and smtp_password is not, Bazaar will prompt for a password.\n"
@@ -10353,13 +10356,13 @@
 "to send mail."
 msgstr ""
 
-#: en/help_topics/configuration.txt:537
+#: en/help_topics/configuration.txt:525
 msgid ""
 "locks.steal_dead\n"
 "~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:540
+#: en/help_topics/configuration.txt:528
 msgid ""
 "If set to true, bzr will automatically break locks held by processes from\n"
 "the same machine and user that are no longer alive.  Otherwise, it will\n"
@@ -10367,13 +10370,13 @@
 "the object is no longer in use."
 msgstr ""
 
-#: en/help_topics/configuration.txt:545
+#: en/help_topics/configuration.txt:533
 msgid ""
 "mail_client\n"
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:548
+#: en/help_topics/configuration.txt:536
 msgid ""
 "A mail client to use for sending merge requests.\n"
 "By default, bzr will try to use ``mapi`` on Windows.  On other platforms, "
@@ -10382,11 +10385,11 @@
 "``editor``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:553
+#: en/help_topics/configuration.txt:541
 msgid "Supported values for specific clients:"
 msgstr ""
 
-#: en/help_topics/configuration.txt:555
+#: en/help_topics/configuration.txt:543
 msgid ""
 ":claws: Use Claws.  This skips a dialog for attaching files.\n"
 ":evolution: Use Evolution.\n"
@@ -10397,11 +10400,11 @@
 "    this works around some bugs that xdg-email doesn't handle."
 msgstr ""
 
-#: en/help_topics/configuration.txt:562
+#: en/help_topics/configuration.txt:550
 msgid "Supported generic values are:"
 msgstr ""
 
-#: en/help_topics/configuration.txt:564
+#: en/help_topics/configuration.txt:552
 msgid ""
 ":default: See above.\n"
 ":editor: Use your editor to compose the merge request.  This also uses\n"
@@ -10411,26 +10414,26 @@
 ":xdg-email: Use xdg-email to run your preferred mail program"
 msgstr ""
 
-#: en/help_topics/configuration.txt:571
+#: en/help_topics/configuration.txt:559
 msgid ""
 "repository.fdatasync\n"
 "~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:574
+#: en/help_topics/configuration.txt:562
 msgid ""
 "If true (default), repository changes are flushed through the OS buffers\n"
 "to physical disk.  This is somewhat slower, but means data should not be\n"
 "lost if the machine crashes.  See also dirstate.fdatasync."
 msgstr ""
 
-#: en/help_topics/configuration.txt:578
+#: en/help_topics/configuration.txt:566
 msgid ""
 "submit_branch\n"
 "~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:581
+#: en/help_topics/configuration.txt:569
 msgid ""
 "The branch you intend to submit your current work to.  This is "
 "automatically\n"
@@ -10439,36 +10442,36 @@
 "should usually be set on a per-branch or per-location basis."
 msgstr ""
 
-#: en/help_topics/configuration.txt:585
+#: en/help_topics/configuration.txt:573
 msgid ""
 "public_branch\n"
 "~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:588
+#: en/help_topics/configuration.txt:576
 msgid ""
 "A publically-accessible version of this branch (implying that this version "
 "is\n"
 "not publically-accessible).  Used (and set) by ``bzr send``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:591
+#: en/help_topics/configuration.txt:579
 msgid ""
 "suppress_warnings\n"
 "~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:594
+#: en/help_topics/configuration.txt:582
 msgid ""
 "A list of strings, each string represent a warning that can be emitted by\n"
 "bzr. Mentioning a warning in this list tells bzr to not emit it."
 msgstr ""
 
-#: en/help_topics/configuration.txt:597
+#: en/help_topics/configuration.txt:585
 msgid "Valid values:"
 msgstr ""
 
-#: en/help_topics/configuration.txt:599
+#: en/help_topics/configuration.txt:587
 msgid ""
 "* ``format_deprecation``:\n"
 "    whether the format deprecation warning is shown on repositories that "
@@ -10476,47 +10479,47 @@
 "    using deprecated formats."
 msgstr ""
 
-#: en/help_topics/configuration.txt:603
+#: en/help_topics/configuration.txt:591
 msgid ""
 "default_format\n"
 "~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:606
+#: en/help_topics/configuration.txt:594
 msgid ""
 "A format name for the default format used when creating branches.  See "
 "``bzr\n"
 "help formats`` for possible values."
 msgstr ""
 
-#: en/help_topics/configuration.txt:609
+#: en/help_topics/configuration.txt:597
 msgid ""
 "\n"
 "Unicode options\n"
 "---------------"
 msgstr ""
 
-#: en/help_topics/configuration.txt:613
+#: en/help_topics/configuration.txt:601
 msgid ""
 "output_encoding\n"
 "~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:616
+#: en/help_topics/configuration.txt:604
 msgid ""
 "A Python unicode encoding name for text output from bzr, such as log\n"
 "information.  Values include: utf8, cp850, ascii, iso-8859-1.  The default\n"
 "is the terminal encoding prefered by the operating system."
 msgstr ""
 
-#: en/help_topics/configuration.txt:620
+#: en/help_topics/configuration.txt:608
 msgid ""
 "\n"
 "Branch type specific options\n"
 "----------------------------"
 msgstr ""
 
-#: en/help_topics/configuration.txt:624
+#: en/help_topics/configuration.txt:612
 msgid ""
 "These options apply only to branches that use the ``dirstate-tags`` or\n"
 "later format.  They\n"
@@ -10524,13 +10527,13 @@
 "manually set in ``locations.conf`` or ``bazaar.conf``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:629
+#: en/help_topics/configuration.txt:617
 msgid ""
 "append_revisions_only\n"
 "~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:632
+#: en/help_topics/configuration.txt:620
 msgid ""
 "If set to \"True\" then revisions can only be appended to the log, not\n"
 "removed.  A branch with this setting enabled can only pull from another\n"
@@ -10540,13 +10543,13 @@
 "compatibility with previous bzr versions (older than 2.2)."
 msgstr ""
 
-#: en/help_topics/configuration.txt:639
+#: en/help_topics/configuration.txt:627
 msgid ""
 "parent_location\n"
 "~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:642
+#: en/help_topics/configuration.txt:630
 msgid ""
 "If present, the location of the default branch for pull or merge.  This "
 "option\n"
@@ -10554,87 +10557,87 @@
 "--remember``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:646
+#: en/help_topics/configuration.txt:634
 msgid ""
 "push_location\n"
 "~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:649
+#: en/help_topics/configuration.txt:637
 msgid ""
 "If present, the location of the default branch for push.  This option\n"
 "is normally set by the first ``push`` or ``push --remember``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:652
+#: en/help_topics/configuration.txt:640
 msgid ""
 "push_strict\n"
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:655
+#: en/help_topics/configuration.txt:643
 msgid ""
 "If present, defines the ``--strict`` option default value for checking\n"
 "uncommitted changes before pushing."
 msgstr ""
 
-#: en/help_topics/configuration.txt:658
+#: en/help_topics/configuration.txt:646
 msgid ""
 "dpush_strict\n"
 "~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:661
+#: en/help_topics/configuration.txt:649
 msgid ""
 "If present, defines the ``--strict`` option default value for checking\n"
 "uncommitted changes before pushing into a different VCS without any\n"
 "custom bzr metadata."
 msgstr ""
 
-#: en/help_topics/configuration.txt:665
+#: en/help_topics/configuration.txt:653
 msgid ""
 "bound_location\n"
 "~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:668
+#: en/help_topics/configuration.txt:656
 msgid ""
 "The location that commits should go to when acting as a checkout.\n"
 "This option is normally set by ``bind``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:671
+#: en/help_topics/configuration.txt:659
 msgid ""
 "bound\n"
 "~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:674
+#: en/help_topics/configuration.txt:662
 msgid ""
 "If set to \"True\", the branch should act as a checkout, and push each "
 "commit to\n"
 "the bound_location.  This option is normally set by ``bind``/``unbind``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:677
+#: en/help_topics/configuration.txt:665
 msgid ""
 "send_strict\n"
 "~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:680
+#: en/help_topics/configuration.txt:668
 msgid ""
 "If present, defines the ``--strict`` option default value for checking\n"
 "uncommitted changes before sending a merge directive."
 msgstr ""
 
-#: en/help_topics/configuration.txt:683
+#: en/help_topics/configuration.txt:671
 msgid ""
 "add.maximum_file_size\n"
 "~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:686
+#: en/help_topics/configuration.txt:674
 msgid ""
 "Defines the maximum file size the command line \"add\" operation will allow\n"
 "in recursive mode, with files larger than this value being skipped. You "
@@ -10646,19 +10649,19 @@
 "will disable skipping."
 msgstr ""
 
-#: en/help_topics/configuration.txt:692
+#: en/help_topics/configuration.txt:680
 msgid ""
 "External Merge Tools\n"
 "--------------------"
 msgstr ""
 
-#: en/help_topics/configuration.txt:695
+#: en/help_topics/configuration.txt:683
 msgid ""
 "bzr.mergetool.<name>\n"
 "~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:698
+#: en/help_topics/configuration.txt:686
 msgid ""
 "Defines an external merge tool called <name> with the given command-line.\n"
 "Arguments containing spaces should be quoted using single or double quotes. "
@@ -10666,14 +10669,14 @@
 "executable may omit its path if it can be found on the PATH."
 msgstr ""
 
-#: en/help_topics/configuration.txt:702
+#: en/help_topics/configuration.txt:690
 msgid ""
 "The following markers can be used in the command-line to substitute "
 "filenames\n"
 "involved in the merge conflict::"
 msgstr ""
 
-#: en/help_topics/configuration.txt:705
+#: en/help_topics/configuration.txt:693
 msgid ""
 "  {base}      file.BASE\n"
 "  {this}      file.THIS\n"
@@ -10684,24 +10687,24 @@
 "              succeeds."
 msgstr ""
 
-#: en/help_topics/configuration.txt:714
+#: en/help_topics/configuration.txt:702
 msgid "  bzr.mergetool.kdiff3 = kdiff3 {base} {this} {other} -o {result}"
 msgstr ""
 
-#: en/help_topics/configuration.txt:716
+#: en/help_topics/configuration.txt:704
 msgid ""
 "bzr.default_mergetool\n"
 "~~~~~~~~~~~~~~~~~~~~~"
 msgstr ""
 
-#: en/help_topics/configuration.txt:719
+#: en/help_topics/configuration.txt:707
 msgid ""
 "Specifies which external merge tool (as defined above) should be selected "
 "by\n"
 "default in tools such as ``bzr qconflicts``."
 msgstr ""
 
-#: en/help_topics/configuration.txt:724
+#: en/help_topics/configuration.txt:712
 msgid "  bzr.default_mergetool = kdiff3\n"
 msgstr ""
 
@@ -11651,50 +11654,6 @@
 "branch can now be pushed to the mainline.\n"
 msgstr ""
 
-#: en/help_topics/env-variables.txt:1
-msgid "Environment Variables"
-msgstr ""
-
-#: en/help_topics/env-variables.txt:3
-msgid ""
-"=================== "
-"===========================================================\n"
-"BZRPATH             Path where bzr is to look for shell plugin external\n"
-"                    commands.\n"
-"BZR_EMAIL           E-Mail address of the user. Overrides EMAIL.\n"
-"EMAIL               E-Mail address of the user.\n"
-"BZR_EDITOR          Editor for editing commit messages. Overrides EDITOR.\n"
-"EDITOR              Editor for editing commit messages.\n"
-"BZR_PLUGIN_PATH     Paths where bzr should look for plugins.\n"
-"BZR_DISABLE_PLUGINS Plugins that bzr should not load.\n"
-"BZR_PLUGINS_AT      Plugins to load from a directory not in "
-"BZR_PLUGIN_PATH.\n"
-"BZR_HOME            Directory holding .bazaar config dir. Overrides HOME.\n"
-"BZR_HOME (Win32)    Directory holding bazaar config dir. Overrides APPDATA "
-"and\n"
-"                    HOME.\n"
-"BZR_REMOTE_PATH     Full name of remote 'bzr' command (for bzr+ssh:// "
-"URLs).\n"
-"BZR_SSH             Path to SSH client, or one of paramiko, openssh, "
-"sshcorp,\n"
-"                    plink or lsh.\n"
-"BZR_LOG             Location of .bzr.log (use '/dev/null' to suppress log).\n"
-"BZR_LOG (Win32)     Location of .bzr.log (use 'NUL' to suppress log).\n"
-"BZR_COLUMNS         Override implicit terminal width.\n"
-"BZR_CONCURRENCY     Number of processes that can be run concurrently "
-"(selftest)\n"
-"BZR_PROGRESS_BAR    Override the progress display. Values are 'none' or "
-"'text'.\n"
-"BZR_PDB             Control whether to launch a debugger on error.\n"
-"BZR_SIGQUIT_PDB     Control whether SIGQUIT behaves normally or invokes a\n"
-"                    breakin debugger.\n"
-"BZR_TEXTUI_INPUT    Force console input mode for prompts to line-based "
-"(instead\n"
-"                    of char-based).\n"
-"=================== "
-"===========================================================\n"
-msgstr ""
-
 #: en/help_topics/eol.txt:1
 msgid ""
 "End of Line Conversion\n"

